@@ -33,21 +33,21 @@ import org.json.JSONObject;
 import android.content.Context;
 import android.os.Handler;
 
-
-class GliderLinkReceiver extends BroadcastReceiver {
+class GliderLinkReceiver
+  extends BroadcastReceiver
+  implements AndroidSensor
+{
   private static final String TAG = "XCSoar";
   public static final String ACTION = "link.glider.gliderlink.target_position";
 
   private final Context context;
 
-  /**
-   * Index of this device in the global list. This value is extracted directly
-   * from this object by the C++ wrapper code.
-   */
-  private final int index;
+  private final SensorListener listener;
 
   private static Handler handler;
 
+  private int state = STATE_LIMBO;
+
   /**
    * Global initialization of the class.  Must be called from the main
    * event thread, because the Handler object must be bound to that
@@ -57,9 +57,9 @@ class GliderLinkReceiver extends BroadcastReceiver {
     handler = new Handler();
   }
 
-  public GliderLinkReceiver(final Context context, int index) {
+  public GliderLinkReceiver(final Context context, SensorListener listener) {
     this.context = context;
-    this.index = index;
+    this.listener = listener;
 
     handler.post(new Runnable() {
       @Override
@@ -69,6 +69,7 @@ class GliderLinkReceiver extends BroadcastReceiver {
     });
   }
 
+  @Override
   public void close() {
     handler.post(new Runnable() {
       @Override
@@ -78,15 +79,21 @@ class GliderLinkReceiver extends BroadcastReceiver {
     });
   }
 
-  private static native void setGliderLinkInfo(int deviceId, long gid, String callsign,
-          double latitude, double longitude, double altitude,
-          double gspeed, double vspeed, int bearing);
+  @Override
+  public int getState() {
+    return state;
+  }
 
   @Override
   public void onReceive(Context context, Intent intent) {
     try {
       JSONObject json = new JSONObject(intent.getStringExtra("json"));
 
+      if (state != STATE_READY) {
+        state = STATE_READY;
+        listener.onSensorStateChanged();
+      }
+
       JSONObject pos = json.getJSONObject("position");
       
       /* Sample data:
@@ -107,9 +114,14 @@ class GliderLinkReceiver extends BroadcastReceiver {
              }
       */
 
-      setGliderLinkInfo(index, pos.getLong("gid"), pos.getString("callsign"), pos.getDouble("latitude"),
-              pos.getDouble("longitude"), pos.getDouble("altitude"), pos.getDouble("gspeed"), pos.getDouble("vspeed"),
-              pos.getInt("bearing"));
+      listener.onGliderLinkTraffic(pos.getLong("gid"),
+                                   pos.getString("callsign"),
+                                   pos.getDouble("latitude"),
+                                   pos.getDouble("longitude"),
+                                   pos.getDouble("altitude"),
+                                   pos.getDouble("gspeed"),
+                                   pos.getDouble("vspeed"),
+                                   pos.getInt("bearing"));
     } catch (JSONException e) {
       Log.e(TAG, e.getLocalizedMessage(), e);
     }
