@@ -29,16 +29,17 @@ import ioio.lib.api.exception.ConnectionLostException;
 /**
  * A driver for the BMP085 pressure sensor, connected via IOIO.
  */
-final class GlueBMP085 implements IOIOConnectionListener {
+final class GlueBMP085 implements AndroidSensor, IOIOConnectionListener {
   private IOIOConnectionHolder holder;
   private final int twiNum, eocPin, oversampling;
-  private final BMP085.Listener listener;
+  private final SensorListener listener;
 
   private BMP085 instance;
+  private int state = STATE_LIMBO;
 
   GlueBMP085(IOIOConnectionHolder _holder,
              int _twiNum, int _eocPin, int _oversampling,
-             BMP085.Listener _listener) {
+             SensorListener _listener) {
     twiNum = _twiNum;
     eocPin = _eocPin;
     oversampling = _oversampling;
@@ -48,6 +49,7 @@ final class GlueBMP085 implements IOIOConnectionListener {
     _holder.addListener(this);
   }
 
+  @Override
   public void close() {
     IOIOConnectionHolder holder;
     synchronized(this) {
@@ -59,9 +61,16 @@ final class GlueBMP085 implements IOIOConnectionListener {
       holder.removeListener(this);
   }
 
+  @Override
+  public int getState() {
+    return state;
+  }
+
   @Override public void onIOIOConnect(IOIO ioio)
     throws ConnectionLostException, InterruptedException {
     instance = new BMP085(ioio, twiNum, eocPin, oversampling, listener);
+    state = STATE_READY;
+    listener.onSensorStateChanged();
   }
 
   @Override public void onIOIODisconnect(IOIO ioio) {
@@ -70,5 +79,8 @@ final class GlueBMP085 implements IOIOConnectionListener {
 
     instance.close();
     instance = null;
+
+    state = STATE_LIMBO;
+    listener.onSensorStateChanged();
   }
 }
