@@ -64,7 +64,7 @@ class NativeView extends SurfaceView
   implements SurfaceHolder.Callback, Runnable {
   private static final String TAG = "XCSoar";
 
-  final Handler quitHandler, errorHandler;
+  final Handler quitHandler, fullScreenHandler, errorHandler;
 
   Resources resources;
 
@@ -97,10 +97,12 @@ class NativeView extends SurfaceView
   Thread thread;
 
   public NativeView(Activity context, Handler _quitHandler,
+                    Handler _fullScreenHandler,
                     Handler _errorHandler) {
     super(context);
 
     quitHandler = _quitHandler;
+    fullScreenHandler = _fullScreenHandler;
     errorHandler = _errorHandler;
 
     resources = context.getResources();
@@ -197,6 +199,12 @@ class NativeView extends SurfaceView
       if (context == EGL10.EGL_NO_CONTEXT)
         throw new EGLException("eglCreateContext() failed: " +
                                egl.eglGetError());
+
+      GL10 gl = (GL10)context.getGL();
+      Log.d(TAG, "OpenGL vendor: " + gl.glGetString(GL10.GL_VENDOR));
+      Log.d(TAG, "OpenGL version: " + gl.glGetString(GL10.GL_VERSION));
+      Log.d(TAG, "OpenGL renderer: " + gl.glGetString(GL10.GL_RENDERER));
+      Log.d(TAG, "OpenGL extensions: " + gl.glGetString(GL10.GL_EXTENSIONS));
     }
 
     surface = egl.eglCreateWindowSurface(display, config,
@@ -207,12 +215,6 @@ class NativeView extends SurfaceView
 
     if (!egl.eglMakeCurrent(display, surface, surface, context))
       throw new EGLException("eglMakeCurrent() failed: " + egl.eglGetError());
-
-    GL10 gl = (GL10)context.getGL();
-    Log.d(TAG, "OpenGL vendor: " + gl.glGetString(GL10.GL_VENDOR));
-    Log.d(TAG, "OpenGL version: " + gl.glGetString(GL10.GL_VERSION));
-    Log.d(TAG, "OpenGL renderer: " + gl.glGetString(GL10.GL_RENDERER));
-    Log.d(TAG, "OpenGL extensions: " + gl.glGetString(GL10.GL_EXTENSIONS));
   }
 
   /**
@@ -274,6 +276,13 @@ class NativeView extends SurfaceView
     config = null;
   }
 
+  /**
+   * Called from native code.
+   */
+  void setFullScreen(boolean fullScreen) {
+    fullScreenHandler.sendEmptyMessage(fullScreen ? 1 : 0);
+  }
+
   private boolean setRequestedOrientation(int requestedOrientation) {
     try {
       ((Activity)getContext()).setRequestedOrientation(requestedOrientation);
@@ -349,11 +358,8 @@ class NativeView extends SurfaceView
       return;
     }
 
-    Log.d(TAG, "deinitializeNative()");
     deinitializeNative();
-
-    Log.d(TAG, "sending message to quitHandler");
-    quitHandler.sendMessage(quitHandler.obtainMessage());
+    quitHandler.sendEmptyMessage(0);
   }
 
   protected native boolean initializeNative(Context context,
@@ -483,9 +489,6 @@ class NativeView extends SurfaceView
     pauseNative();
   }
 
-  public void exitApp() {
-  }
-
   private final int translateKeyCode(int keyCode) {
     if (!hasKeyboard) {
       /* map the volume keys to cursor up/down if the device has no
