@@ -29,7 +29,6 @@ import android.os.Bundle;
 import android.view.MotionEvent;
 import android.view.KeyEvent;
 import android.view.Window;
-import android.view.WindowManager;
 import android.widget.TextView;
 import android.os.Build;
 import android.os.Environment;
@@ -46,7 +45,6 @@ import android.content.ComponentName;
 import android.content.pm.PackageManager;
 import android.util.Log;
 import android.provider.Settings;
-import android.view.View;
 
 public class XCSoar extends Activity {
   private static final String TAG = "XCSoar";
@@ -63,6 +61,8 @@ public class XCSoar extends Activity {
 
   BatteryReceiver batteryReceiver;
 
+  boolean fullScreen = false;
+
   @Override protected void onCreate(Bundle savedInstanceState) {
     if (serviceClass == null)
       serviceClass = MyService.class;
@@ -96,7 +96,8 @@ public class XCSoar extends Activity {
 
     IOIOHelper.onCreateContext(this);
 
-    enterFullScreenMode();
+    final Window window = getWindow();
+    window.requestFeature(Window.FEATURE_NO_TITLE);
 
     TextView tv = new TextView(this);
     tv.setText("Loading XCSoar...");
@@ -114,15 +115,12 @@ public class XCSoar extends Activity {
   }
 
   private void quit() {
-    Log.d(TAG, "in quit()");
-
     nativeView = null;
 
     TextView tv = new TextView(XCSoar.this);
     tv.setText("Shutting down XCSoar...");
     setContentView(tv);
 
-    Log.d(TAG, "finish()");
     finish();
   }
 
@@ -138,18 +136,35 @@ public class XCSoar extends Activity {
       TextView tv = new TextView(XCSoar.this);
       tv.setText(msg.obj.toString());
       setContentView(tv);
-
     }
   };
 
-  public void initSDL() {
+  final Handler fullScreenHandler = new Handler() {
+      public void handleMessage(Message msg) {
+        fullScreen = msg.what != 0;
+        applyFullScreen();
+      }
+    };
+
+  boolean wantFullScreen() {
+    return Loader.loaded && fullScreen && !isInMultiWindowMode();
+  }
+
+  void applyFullScreen() {
+    final Window window = getWindow();
+    if (wantFullScreen())
+      WindowUtil.enterFullScreenMode(window);
+    else
+      WindowUtil.leaveFullScreenMode(window);
+  }
+
+  public void initNative() {
     if (!Loader.loaded)
       return;
 
     /* check if external storage is available; XCSoar doesn't work as
        long as external storage is being forwarded to a PC */
     String state = Environment.getExternalStorageState();
-    Log.d(TAG, "getExternalStorageState() = " + state);
     if (!Environment.MEDIA_MOUNTED.equals(state)) {
       TextView tv = new TextView(this);
       tv.setText("External storage is not available (state='" + state
@@ -158,7 +173,8 @@ public class XCSoar extends Activity {
       return;
     }
 
-    nativeView = new NativeView(this, quitHandler, errorHandler);
+    nativeView = new NativeView(this, quitHandler, fullScreenHandler,
+                                errorHandler);
     setContentView(nativeView);
     // Receive keyboard events
     nativeView.setFocusableInTouchMode(true);
@@ -197,32 +213,6 @@ public class XCSoar extends Activity {
       nativeView.setHapticFeedback(hapticFeedbackEnabled);
   }
 
-  private void enterFullScreenMode() {
-    // fullscreen mode
-    requestWindowFeature(Window.FEATURE_NO_TITLE);
-
-    Window window = getWindow();
-    window.addFlags(WindowManager.LayoutParams.FLAG_FULLSCREEN|
-                    WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON);
-
-    /* Workaround for layout problems in Android KitKat with immersive full
-       screen mode: Sometimes the content view was not initialized with the
-       correct size, which caused graphics artifacts. */
-    window.addFlags(WindowManager.LayoutParams.FLAG_LAYOUT_IN_SCREEN|
-                    WindowManager.LayoutParams.FLAG_LAYOUT_NO_LIMITS|
-                    WindowManager.LayoutParams.FLAG_LAYOUT_INSET_DECOR|
-                    WindowManager.LayoutParams.FLAG_TRANSLUCENT_NAVIGATION);
-
-    // Set / Reset the System UI visibility flags for Immersive Full Screen Mode
-    View decorView = window.getDecorView();
-    decorView.setSystemUiVisibility(View.SYSTEM_UI_FLAG_FULLSCREEN|
-                                    View.SYSTEM_UI_FLAG_HIDE_NAVIGATION|
-                                    View.SYSTEM_UI_FLAG_IMMERSIVE_STICKY|
-                                    View.SYSTEM_UI_FLAG_LAYOUT_FULLSCREEN|
-                                    View.SYSTEM_UI_FLAG_LAYOUT_HIDE_NAVIGATION|
-                                    View.SYSTEM_UI_FLAG_LAYOUT_STABLE);
-  }
-
   private static final String[] NEEDED_PERMISSIONS = new String[] {
     Manifest.permission.ACCESS_FINE_LOCATION,
     Manifest.permission.WRITE_EXTERNAL_STORAGE
@@ -266,7 +256,7 @@ public class XCSoar extends Activity {
     if (nativeView != null)
       nativeView.onResume();
     else
-      initSDL();
+      initNative();
     getHapticFeedbackSettings();
   }
 
@@ -277,17 +267,12 @@ public class XCSoar extends Activity {
       return;
     }
 
-    Log.d(TAG, "in onDestroy()");
-
     if (batteryReceiver != null) {
       unregisterReceiver(batteryReceiver);
       batteryReceiver = null;
     }
 
-    if (nativeView != null) {
-      nativeView.exitApp();
-      nativeView = null;
-    }
+    nativeView = null;
 
     // Release the WakeLock instance to re-enable screen timeouts
     if (wakeLock != null) {
@@ -298,7 +283,6 @@ public class XCSoar extends Activity {
     IOIOHelper.onDestroyContext();
 
     super.onDestroy();
-    Log.d(TAG, "System.exit()");
     System.exit(0);
   }
 
@@ -319,6 +303,21 @@ public class XCSoar extends Activity {
       return super.onKeyUp(keyCode, event);
   }
 
+  @Override public void onWindowFocusChanged(boolean hasFocus) {
+    if (hasFocus && wantFullScreen())
+      /* some Android don't restore immersive mode after returning to
+         this app, so unfortunately we need to reapply those settings
+         manually */
+      WindowUtil.enableImmersiveMode(getWindow());
+
+    super.onWindowFocusChanged(hasFocus);
+  }
+
+  @Override
+  public void onMultiWindowModeChanged(boolean isInMultiWindowMode) {
+    applyFullScreen();
+  }
+
   @Override public boolean dispatchTouchEvent(final MotionEvent ev) {
     if (nativeView != null) {
       nativeView.onTouchEvent(ev);
