@@ -152,7 +152,7 @@ void FlightTimes(DebugReplay &replay, std::vector<FlightTimeResult> &results)
         && result.landing_time.IsPlausible()) {
 
       if (result.release_time.IsPlausible() &&
-          result.release_time.ToUnixTimeUTC() < result.takeoff_time.ToUnixTimeUTC())
+          result.release_time < result.takeoff_time)
         result.release_time = result.takeoff_time;
 
       results.push_back(result);
