@@ -1,7 +1,7 @@
 /* Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -25,6 +25,10 @@
 
 #include <Python.h>
 
-PyMODINIT_FUNC initxcsoar();
+#if PY_MAJOR_VERSION >= 3
+  PyMODINIT_FUNC PyInit_xcsoar();
+#else
+  PyMODINIT_FUNC initxcsoar();
+#endif
 
 #endif /* PYTHON_PYTHONGLUE_HPP */
