@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -24,16 +24,21 @@ Copyright_License {
 #ifndef XCSOAR_ANDROID_CONTEXT_HPP
 #define XCSOAR_ANDROID_CONTEXT_HPP
 
-#include "Java/Object.hxx"
+#include "java/Object.hxx"
 
-class Context : public Java::Object {
+class AllocatedPath;
+
+class Context : public Java::GlobalObject {
 public:
-  Context(JNIEnv *env, jobject obj):Java::Object(env, obj) {
+  Context(JNIEnv *env, jobject obj):Java::GlobalObject(env, obj) {
   }
 
-  jobject GetSystemService(JNIEnv *env, jstring name);
-  jobject GetSystemService(JNIEnv *env, const char *name);
-  jobject GetVibrator(JNIEnv *env);
+  AllocatedPath GetExternalFilesDir(JNIEnv *env) noexcept;
+  AllocatedPath GetExternalCacheDir(JNIEnv *env) noexcept;
+
+  Java::LocalObject GetSystemService(JNIEnv *env, jstring name);
+  Java::LocalObject GetSystemService(JNIEnv *env, const char *name);
+  Java::LocalObject GetVibrator(JNIEnv *env);
 };
 
 #endif
