@@ -21,41 +21,25 @@ Copyright_License {
 }
 */
 
-#ifdef ANDROID
-
 #ifndef XCSOAR_ANDROID_GLIDER_LINK_HPP
 #define XCSOAR_ANDROID_GLIDER_LINK_HPP
 
 #include "java/Object.hxx"
-#include "java/Class.hxx"
-#include "util/Compiler.h"
-
-#include <jni.h>
-#include <vector>
 
 class Context;
+class SensorListener;
 
-class GliderLink {
-  static Java::TrivialClass gl_cls;
+namespace GliderLink {
 
-  // IDs for methods in GliderLinkReceiver.java.
-  static jmethodID gl_ctor_id, close_method;
-private:
-  Java::GlobalObject obj;
+void
+Initialise(JNIEnv *env) noexcept;
 
-public:
-  static bool Initialise(JNIEnv *env);
-  static void Deinitialise(JNIEnv *env);
+void
+Deinitialise(JNIEnv *env) noexcept;
 
-  GliderLink(JNIEnv *env, jobject obj);
+Java::LocalObject
+Create(JNIEnv *env, Context &context, SensorListener &listener);
 
-  ~GliderLink();
-
-  gcc_malloc
-  static GliderLink *create(JNIEnv* env, Context* native_view,
-                                 unsigned int index);
-};
-
-#endif
+} // namespace GliderLink
 
 #endif
