@@ -45,6 +45,7 @@ class NativeView {
   static Java::TrivialClass cls;
   static jfieldID textureNonPowerOfTwo_field;
   static jmethodID init_surface_method, deinit_surface_method;
+  static jmethodID setFullScreen_method;
   static jmethodID setRequestedOrientationID;
   static jmethodID loadResourceBitmap_method;
   static jmethodID loadFileBitmap_method;
@@ -106,6 +107,10 @@ public:
     env->CallVoidMethod(obj, deinit_surface_method);
   }
 
+  void SetFullScreen(bool full_screen) const noexcept {
+    return env->CallVoidMethod(obj, setFullScreen_method, full_screen);
+  }
+
   bool setRequestedOrientation(ScreenOrientation so) {
     return env->CallBooleanMethod(obj, setRequestedOrientationID, (jint)so);
   }
