@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -24,14 +24,14 @@ Copyright_License {
 #ifndef XCSOAR_ANDROID_VIBRATOR_HPP
 #define XCSOAR_ANDROID_VIBRATOR_HPP
 
-#include "Java/Object.hxx"
+#include "java/Object.hxx"
 
 class Context;
 
 class Vibrator {
   static jmethodID cancel_method, vibrate_method;
 
-  Java::Object object;
+  Java::GlobalObject object;
 
 public:
   /**
