@@ -62,12 +62,12 @@ public:
   void SetComputerSettings(const ComputerSettings &new_value);
   void SetScreenDistanceMeters(double new_value);
 
-  bool Start(bool suspended=false) {
-    if (!WorkerThread::Start(suspended))
-      return false;
-
+  /**
+   * Throws on error.
+   */
+  void Start(bool suspended=false) {
+    WorkerThread::Start(suspended);
     SetLowPriority();
-    return true;
   }
 
   void ForceTrigger();
