@@ -27,6 +27,8 @@ Copyright_License {
 #include "Geo/Geoid.hpp"
 #include "time/FloatDuration.hxx"
 
+using namespace std::chrono;
+
 void
 DeviceDescriptor::OnConnected(int connected) noexcept
 {
@@ -59,12 +61,11 @@ void
 DeviceDescriptor::OnLocationSensor(std::chrono::system_clock::time_point time,
                                    int n_satellites,
                                    GeoPoint location,
-                                   bool hasAltitude, double altitude,
+                                   bool hasAltitude, bool geoid_altitude,
+                                   double altitude,
                                    bool hasBearing, double bearing,
                                    bool hasSpeed, double ground_speed,
-                                   bool hasAccuracy, double accuracy,
-                                   bool hasAcceleration,
-                                   double acceleration) noexcept
+                                   bool hasAccuracy, double accuracy) noexcept
 {
   const auto e = BeginEdit();
   NMEAInfo &basic = *e;
@@ -73,14 +74,8 @@ DeviceDescriptor::OnLocationSensor(std::chrono::system_clock::time_point time,
 
   const BrokenDateTime date_time{time};
   const BrokenDateTime midnight = date_time.AtMidnight();
-  double second_of_day =
-    std::chrono::duration_cast<FloatDuration>(time - midnight.ToTimePoint()).count();
-
-  if (second_of_day < basic.time &&
-      basic.date_time_utc.IsDatePlausible() &&
-      date_time.GetDate() > basic.date_time_utc.GetDate())
-    /* don't wrap around when going past midnight in UTC */
-    second_of_day += 24u * 3600u;
+  TimeStamp second_of_day{
+    duration_cast<FloatDuration>(time - midnight.ToTimePoint())};
 
   basic.time = second_of_day;
   basic.time_available.Update(basic.clock);
@@ -94,7 +89,9 @@ DeviceDescriptor::OnLocationSensor(std::chrono::system_clock::time_point time,
   basic.location_available.Update(basic.clock);
 
   if (hasAltitude) {
-    auto GeoidSeparation = EGM96::LookupSeparation(basic.location);
+    auto GeoidSeparation = geoid_altitude
+      ? 0.
+      : EGM96::LookupSeparation(basic.location);
     basic.gps_altitude = altitude - GeoidSeparation;
     basic.gps_altitude_available.Update(basic.clock);
   } else
@@ -113,12 +110,23 @@ DeviceDescriptor::OnLocationSensor(std::chrono::system_clock::time_point time,
 
   basic.gps.hdop = hasAccuracy ? accuracy : -1;
 
-  if (hasAcceleration)
-    basic.acceleration.ProvideGLoad(acceleration, true);
-
   e.Commit();
 }
 
+#ifdef ANDROID
+
+void
+DeviceDescriptor::OnAccelerationSensor(double acceleration) noexcept
+{
+  const auto e = BeginEdit();
+  NMEAInfo &basic = *e;
+  basic.UpdateClock();
+  basic.alive.Update(basic.clock);
+
+  basic.acceleration.ProvideGLoad(acceleration);
+
+  e.Commit();
+}
 
 void
 DeviceDescriptor::OnAccelerationSensor(float ddx, float ddy,
@@ -349,7 +357,7 @@ DeviceDescriptor::OnNunchukValues(int joy_x, int joy_y,
       const auto e = BeginEdit();
       NMEAInfo &basic = *e;
       basic.UpdateClock();
-      basic.acceleration.ProvideGLoad(acc_z / 1000., true);
+      basic.acceleration.ProvideGLoad(acc_z / 1000.);
       e.Commit();
     }
 
@@ -439,6 +447,34 @@ DeviceDescriptor::OnGliderLinkTraffic(GliderLinkId id, const char *callsign,
   e.Commit();
 }
 
+void
+DeviceDescriptor::OnTemperature(Temperature temperature) noexcept
+{
+  const auto e = BeginEdit();
+  NMEAInfo &basic = *e;
+  basic.UpdateClock();
+  basic.alive.Update(basic.clock);
+
+  basic.temperature = temperature;
+  basic.temperature_available = true;
+
+  e.Commit();
+}
+
+void
+DeviceDescriptor::OnBatteryPercent(double battery_percent) noexcept
+{
+  const auto e = BeginEdit();
+  NMEAInfo &basic = *e;
+  basic.UpdateClock();
+  basic.alive.Update(basic.clock);
+
+  basic.battery_level = battery_percent;
+  basic.battery_level_available.Update(basic.clock);
+
+  e.Commit();
+}
+
 void
 DeviceDescriptor::OnSensorStateChanged() noexcept
 {
@@ -450,3 +486,5 @@ DeviceDescriptor::OnSensorError(const char *msg) noexcept
 {
   PortError(msg);
 }
+
+#endif
