@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -24,10 +24,9 @@ Copyright_License {
 #if !defined(XCSOAR_DIALOGS_H)
 #define XCSOAR_DIALOGS_H
 
-class SingleWindow;
+namespace UI { class SingleWindow; }
 
 void dlgBasicSettingsShowModal();
-void dlgBrightnessShowModal();
 
 void dlgChecklistShowModal();
 void dlgConfigurationShowModal();
@@ -37,8 +36,8 @@ void ShowWindSettingsDialog();
 
 void dlgStatusShowModal(int page);
 
-void dlgCreditsShowModal(SingleWindow &parent);
+void dlgCreditsShowModal(UI::SingleWindow &parent);
 
-void dlgQuickMenuShowModal(SingleWindow &parent);
+void dlgQuickMenuShowModal(UI::SingleWindow &parent);
 
 #endif
