@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2011 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -25,7 +25,7 @@ Copyright_License {
 #define XCSOAR_DIALOGS_GEOPOINT_ENTRY_HPP
 
 #include <tchar.h>
-#include <stdint.h>
+#include <cstdint>
 
 enum class CoordinateFormat : uint8_t;
 struct GeoPoint;
