@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -22,6 +22,7 @@ Copyright_License {
 */
 
 #include "PlaneDialogs.hpp"
+#include "Dialogs/Error.hpp"
 #include "Dialogs/Message.hpp"
 #include "Dialogs/WidgetDialog.hpp"
 #include "Widget/ListWidget.hpp"
@@ -30,9 +31,8 @@ Copyright_License {
 #include "Plane/Plane.hpp"
 #include "Plane/PlaneGlue.hpp"
 #include "Plane/PlaneFileGlue.hpp"
-#include "OS/FileUtil.hpp"
-#include "OS/PathName.hpp"
-#include "Compatibility/path.h"
+#include "system/FileUtil.hpp"
+#include "system/Path.hpp"
 #include "LocalPath.hpp"
 #include "Components.hpp"
 #include "Profile/Profile.hpp"
@@ -41,11 +41,10 @@ Copyright_License {
 #include "Look/DialogLook.hpp"
 #include "Interface.hpp"
 #include "Language/Language.hpp"
-#include "Util/StringAPI.hxx"
+#include "util/StringAPI.hxx"
 
 #include <vector>
-#include <assert.h>
-#include <windef.h> /* for MAX_PATH */
+#include <cassert>
 
 /* this macro exists in the WIN32 API */
 #ifdef DELETE
@@ -53,13 +52,13 @@ Copyright_License {
 #endif
 
 class PlaneListWidget final
-  : public ListWidget, private ActionListener {
+  : public ListWidget {
 
   struct ListItem {
     StaticString<32> name;
-    StaticString<MAX_PATH> path;
+    AllocatedPath path;
 
-    ListItem(const TCHAR *_name, const TCHAR *_path)
+    ListItem(const TCHAR *_name, Path _path)
       :name(_name), path(_path) {}
 
     bool operator<(const ListItem &i2) const {
@@ -74,18 +73,11 @@ class PlaneListWidget final
   public:
     PlaneFileVisitor(std::vector<ListItem> &_list):list(_list) {}
 
-    void Visit(const TCHAR* path, const TCHAR* filename) {
-      list.emplace_back(filename, path);
+    void Visit(Path path, Path filename) override {
+      list.emplace_back(filename.c_str(), path);
     }
   };
 
-  enum Buttons {
-    NEW,
-    EDIT,
-    DELETE,
-    LOAD,
-  };
-
   WndForm *form;
   Button *edit_button, *delete_button, *load_button;
 
@@ -108,23 +100,19 @@ private:
 
 public:
   /* virtual methods from class Widget */
-  void Prepare(ContainerWindow &parent, const PixelRect &rc) override;
-  void Unprepare() override;
+  void Prepare(ContainerWindow &parent, const PixelRect &rc) noexcept override;
 
 protected:
   /* virtual methods from ListItemRenderer */
-  void OnPaintItem(Canvas &canvas, const PixelRect rc, unsigned idx) override;
+  void OnPaintItem(Canvas &canvas, const PixelRect rc,
+                   unsigned idx) noexcept override;
 
   /* virtual methods from ListCursorHandler */
-  bool CanActivateItem(gcc_unused unsigned index) const override {
+  bool CanActivateItem(gcc_unused unsigned index) const noexcept override {
     return true;
   }
 
-  void OnActivateItem(unsigned index) override;
-
-private:
-  /* virtual methods from class ActionListener */
-  void OnAction(int id) override;
+  void OnActivateItem(unsigned index) noexcept override;
 };
 
 void
@@ -155,14 +143,14 @@ PlaneListWidget::CreateButtons(WidgetDialog &dialog)
 {
   form = &dialog;
 
-  dialog.AddButton(_("New"), *this, NEW);
-  edit_button = dialog.AddButton(_("Edit"), *this, EDIT);
-  delete_button = dialog.AddButton(_("Delete"), *this, DELETE);
-  load_button = dialog.AddButton(_("Activate"), *this, LOAD);
+  dialog.AddButton(_("New"), [this](){ NewClicked(); });
+  edit_button = dialog.AddButton(_("Edit"), [this](){ EditClicked(); });
+  delete_button = dialog.AddButton(_("Delete"), [this](){ DeleteClicked(); });
+  load_button = dialog.AddButton(_("Activate"), [this](){ LoadClicked(); });
 }
 
 void
-PlaneListWidget::Prepare(ContainerWindow &parent, const PixelRect &rc)
+PlaneListWidget::Prepare(ContainerWindow &parent, const PixelRect &rc) noexcept
 {
   const DialogLook &look = UIGlobals::GetDialogLook();
   CreateList(parent, look, rc,
@@ -172,13 +160,8 @@ PlaneListWidget::Prepare(ContainerWindow &parent, const PixelRect &rc)
 }
 
 void
-PlaneListWidget::Unprepare()
-{
-  DeleteWindow();
-}
-
-void
-PlaneListWidget::OnPaintItem(Canvas &canvas, const PixelRect rc, unsigned i)
+PlaneListWidget::OnPaintItem(Canvas &canvas, const PixelRect rc,
+                             unsigned i) noexcept
 {
   assert(i < list.size());
 
@@ -189,11 +172,11 @@ PlaneListWidget::OnPaintItem(Canvas &canvas, const PixelRect rc, unsigned i)
   } else
     row_renderer.DrawFirstRow(canvas, rc, list[i].name);
 
-  row_renderer.DrawSecondRow(canvas, rc, list[i].path);
+  row_renderer.DrawSecondRow(canvas, rc, list[i].path.c_str());
 }
 
 static bool
-LoadFile(const TCHAR *path)
+LoadFile(Path path)
 {
   ComputerSettings &settings = CommonInterface::SetComputerSettings();
 
@@ -254,8 +237,7 @@ PlaneListWidget::NewClicked()
     StaticString<42> filename(plane.registration);
     filename += _T(".xcp");
 
-    StaticString<MAX_PATH> buffer;
-    const auto path = LocalPath(buffer.buffer(), filename);
+    const auto path = LocalPath(filename);
 
     if (File::Exists(path)) {
       StaticString<256> tmp;
@@ -266,7 +248,13 @@ PlaneListWidget::NewClicked()
         continue;
     }
 
-    PlaneGlue::WriteFile(plane, path);
+    try {
+      PlaneGlue::WriteFile(plane, path);
+    } catch (...) {
+      ShowError(std::current_exception(), _("Failed to save file."));
+      return;
+    }
+
     UpdateList();
     break;
   }
@@ -278,7 +266,7 @@ PlaneListWidget::EditClicked()
   assert(GetList().GetCursorIndex() < list.size());
 
   const unsigned index = GetList().GetCursorIndex();
-  const TCHAR *old_path = list[index].path;
+  const Path old_path = list[index].path;
   const TCHAR *old_filename = list[index].name;
 
   Plane plane;
@@ -295,10 +283,8 @@ PlaneListWidget::EditClicked()
     filename += _T(".xcp");
 
     if (filename != old_filename) {
-      StaticString<MAX_PATH> path;
-      DirName(old_path, path.buffer());
-      path += _T(DIR_SEPARATOR_S);
-      path += filename;
+      const auto path = AllocatedPath::Build(old_path.GetParent(),
+                                             filename);
 
       if (File::Exists(path)) {
         StaticString<256> tmp;
@@ -310,14 +296,27 @@ PlaneListWidget::EditClicked()
       }
 
       File::Delete(old_path);
-      PlaneGlue::WriteFile(plane, path);
+
+      try {
+        PlaneGlue::WriteFile(plane, path);
+      } catch (...) {
+        ShowError(std::current_exception(), _("Failed to save file."));
+        return;
+      }
+
       if (Profile::GetPathIsEqual("PlanePath", old_path)) {
-        list[index].path = path;
+        list[index].path = Path(path);
         list[index].name = filename;
         Load(index);
       }
     } else {
-      PlaneGlue::WriteFile(plane, old_path);
+      try {
+        PlaneGlue::WriteFile(plane, old_path);
+      } catch (...) {
+        ShowError(std::current_exception(), _("Failed to save file."));
+        return;
+      }
+
       if (Profile::GetPathIsEqual("PlanePath", old_path))
         Load(index);
     }
@@ -347,29 +346,7 @@ PlaneListWidget::DeleteClicked()
 }
 
 void
-PlaneListWidget::OnAction(int id)
-{
-  switch ((Buttons)id) {
-  case NEW:
-    NewClicked();
-    break;
-
-  case EDIT:
-    EditClicked();
-    break;
-
-  case DELETE:
-    DeleteClicked();
-    break;
-
-  case LOAD:
-    LoadClicked();
-    break;
-  }
-}
-
-void
-PlaneListWidget::OnActivateItem(unsigned i)
+PlaneListWidget::OnActivateItem(unsigned i) noexcept
 {
   assert(i < list.size());
 
@@ -384,13 +361,14 @@ PlaneListWidget::OnActivateItem(unsigned i)
 void
 dlgPlanesShowModal()
 {
-  PlaneListWidget widget;
-  WidgetDialog dialog(UIGlobals::GetDialogLook());
-  dialog.CreateFull(UIGlobals::GetMainWindow(), _("Planes"), &widget);
+  TWidgetDialog<PlaneListWidget>
+    dialog(WidgetDialog::Full{}, UIGlobals::GetMainWindow(),
+           UIGlobals::GetDialogLook(),
+           _("Planes"));
+  dialog.SetWidget();
   dialog.AddButton(_("Close"), mrOK);
-  widget.CreateButtons(dialog);
+  dialog.GetWidget().CreateButtons(dialog);
   dialog.EnableCursorSelection();
 
   dialog.ShowModal();
-  dialog.StealWidget();
 }
