@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -24,16 +24,19 @@ Copyright_License {
 #ifndef XCSOAR_TASK_EDIT_PANEL_HPP
 #define XCSOAR_TASK_EDIT_PANEL_HPP
 
+#include <memory>
+
 class Widget;
 class TaskManagerDialog;
 struct TaskLook;
 struct AirspaceLook;
 class OrderedTask;
 
-Widget *
+std::unique_ptr<Widget>
 CreateTaskEditPanel(TaskManagerDialog &dialog,
                     const TaskLook &task_look,
                     const AirspaceLook &airspace_look,
-                    OrderedTask **active_task, bool *task_modified);
+                    std::unique_ptr<OrderedTask> &active_task,
+                    bool *task_modified) noexcept;
 
 #endif
