@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -28,24 +28,24 @@ Copyright_License {
 #include "Dialogs/TextEntry.hpp"
 #include "Form/Button.hpp"
 #include "Form/ButtonPanel.hpp"
-#include "Form/Frame.hpp"
 #include "Form/List.hpp"
 #include "Widget/ListWidget.hpp"
 #include "Widget/TextWidget.hpp"
 #include "Widget/ButtonPanelWidget.hpp"
 #include "Widget/TwoWidgets.hpp"
 #include "Task/TaskStore.hpp"
-#include "Components.hpp"
+#include "Task/ValidationErrorStrings.hpp"
 #include "LocalPath.hpp"
-#include "OS/FileUtil.hpp"
+#include "system/FileUtil.hpp"
 #include "Language/Language.hpp"
 #include "Interface.hpp"
-#include "Screen/Canvas.hpp"
-#include "Screen/Layout.hpp"
+#include "Renderer/TextRowRenderer.hpp"
+#include "Look/DialogLook.hpp"
 #include "Engine/Task/Ordered/OrderedTask.hpp"
+#include "util/StringCompare.hxx"
+#include "UIGlobals.hpp"
 
-#include <assert.h>
-#include <windef.h>
+#include <cassert>
 
 static unsigned task_list_serial;
 
@@ -55,20 +55,16 @@ static unsigned task_list_serial;
 #endif
 
 class TaskListPanel final
-  : public ListWidget, private ActionListener {
-  enum Buttons {
-    LOAD = 100,
-    RENAME,
-    DELETE,
-    MORE,
-  };
+  : public ListWidget {
 
   TaskManagerDialog &dialog;
 
-  OrderedTask **active_task;
+  TextRowRenderer row_renderer;
+
+  std::unique_ptr<OrderedTask> &active_task;
   bool *task_modified;
 
-  TaskStore *task_store;
+  TaskStore task_store;
   unsigned serial;
 
   /**
@@ -83,7 +79,7 @@ class TaskListPanel final
 
 public:
   TaskListPanel(TaskManagerDialog &_dialog,
-                OrderedTask **_active_task, bool *_task_modified,
+                std::unique_ptr<OrderedTask> &_active_task, bool *_task_modified,
                 TextWidget &_summary)
     :dialog(_dialog),
      active_task(_active_task), task_modified(_task_modified),
@@ -99,10 +95,10 @@ public:
   }
 
   void CreateButtons(ButtonPanel &buttons) {
-    buttons.Add(_("Load"), *this, LOAD);
-    buttons.Add(_("Rename"), *this, RENAME);
-    buttons.Add(_("Delete"), *this, DELETE);
-    more_button = buttons.Add(_("More"), *this, MORE);
+    buttons.Add(_("Load"), [this](){ LoadTask(); });
+    buttons.Add(_("Rename"), [this](){ RenameTask(); });
+    buttons.Add(_("Delete"), [this](){ DeleteTask(); });
+    more_button = buttons.Add(_("More"), [this](){ OnMoreClicked(); });
   }
 
   void RefreshView();
@@ -113,10 +109,9 @@ public:
 
   void OnMoreClicked();
 
-  void Prepare(ContainerWindow &parent, const PixelRect &rc) override;
-  void Unprepare() override;
-  void Show(const PixelRect &rc) override;
-  void Hide() override;
+  void Prepare(ContainerWindow &parent, const PixelRect &rc) noexcept override;
+  void Show(const PixelRect &rc) noexcept override;
+  void Hide() noexcept override;
 
 protected:
   const OrderedTask *get_cursor_task();
@@ -125,21 +120,19 @@ protected:
   const TCHAR *get_cursor_name();
 
 private:
-  /* virtual methods from ActionListener */
-  void OnAction(int id) override;
-
   /* virtual methods from class ListControl::Handler */
-  void OnPaintItem(Canvas &canvas, const PixelRect rc, unsigned idx) override;
+  void OnPaintItem(Canvas &canvas, const PixelRect rc,
+                   unsigned idx) noexcept override;
 
-  void OnCursorMoved(unsigned index) override {
+  void OnCursorMoved(unsigned index) noexcept override {
     RefreshView();
   }
 
-  bool CanActivateItem(unsigned index) const override {
+  bool CanActivateItem(unsigned index) const noexcept override {
       return true;
   }
 
-  void OnActivateItem(unsigned index) override {
+  void OnActivateItem(unsigned index) noexcept override {
     LoadTask();
   }
 };
@@ -153,14 +146,14 @@ const OrderedTask *
 TaskListPanel::get_cursor_task()
 {
   const unsigned cursor_index = GetList().GetCursorIndex();
-  if (cursor_index >= task_store->Size())
+  if (cursor_index >= task_store.Size())
     return nullptr;
 
   const OrderedTask *ordered_task =
-    task_store->GetTask(cursor_index,
-                        CommonInterface::GetComputerSettings().task);
+    task_store.GetTask(cursor_index,
+                       CommonInterface::GetComputerSettings().task);
 
-  if (ordered_task == nullptr || !ordered_task->CheckTask())
+  if (ordered_task == nullptr)
     return nullptr;
 
   return ordered_task;
@@ -170,50 +163,25 @@ const TCHAR *
 TaskListPanel::get_cursor_name()
 {
   const unsigned cursor_index = GetList().GetCursorIndex();
-  if (cursor_index >= task_store->Size())
+  if (cursor_index >= task_store.Size())
     return _T("");
 
-  return task_store->GetName(cursor_index);
-}
-
-void
-TaskListPanel::OnAction(int id)
-{
-  switch (id) {
-  case LOAD:
-    LoadTask();
-    break;
-
-  case RENAME:
-    RenameTask();
-    break;
-
-  case DELETE:
-    DeleteTask();
-    break;
-
-  case MORE:
-    OnMoreClicked();
-    break;
-  }
+  return task_store.GetName(cursor_index);
 }
 
 void
 TaskListPanel::OnPaintItem(Canvas &canvas, const PixelRect rc,
-                           unsigned DrawListIndex)
+                           unsigned DrawListIndex) noexcept
 {
-  assert(DrawListIndex <= task_store->Size());
+  assert(DrawListIndex <= task_store.Size());
 
-  const unsigned padding = Layout::GetTextPadding();
-  const TCHAR *name = task_store->GetName(DrawListIndex);
-
-  canvas.DrawText(rc.left + padding, rc.top + padding, name);
+  row_renderer.DrawTextRow(canvas, rc, task_store.GetName(DrawListIndex));
 }
 
 void
 TaskListPanel::RefreshView()
 {
-  GetList().SetLength(task_store->Size());
+  GetList().SetLength(task_store.Size());
 
   dialog.InvalidateTaskView();
 
@@ -243,17 +211,20 @@ TaskListPanel::LoadTask()
   text.Format(_T("%s\n(%s)"), _("Load the selected task?"),
               get_cursor_name());
 
+  if (const auto errors = orig->CheckTask(); !errors.IsEmpty()) {
+    text.append(_T("\n"));
+    text.append(getTaskValidationErrors(errors));
+  }
+
   if (ShowMessageBox(text.c_str(), _("Task Browser"),
                   MB_YESNO | MB_ICONQUESTION) != IDYES)
     return;
 
   // create new task first to guarantee pointers are different
-  OrderedTask* temptask = orig->Clone(CommonInterface::GetComputerSettings().task);
-  delete *active_task;
-  *active_task = temptask;
+  active_task = orig->Clone(CommonInterface::GetComputerSettings().task);
 
   const unsigned cursor_index = GetList().GetCursorIndex();
-  (*active_task)->SetName(StaticString<64>(task_store->GetName(cursor_index)));
+  active_task->SetName(StaticString<64>(task_store.GetName(cursor_index)));
 
   RefreshView();
   *task_modified = true;
@@ -265,17 +236,17 @@ void
 TaskListPanel::DeleteTask()
 {
   const unsigned cursor_index = GetList().GetCursorIndex();
-  if (cursor_index >= task_store->Size())
+  if (cursor_index >= task_store.Size())
     return;
 
-  const TCHAR *path = task_store->GetPath(cursor_index);
-  if (StringEndsWithIgnoreCase(path, _T(".cup"))) {
+  const auto path = task_store.GetPath(cursor_index);
+  if (StringEndsWithIgnoreCase(path.c_str(), _T(".cup"))) {
     ShowMessageBox(_("Can't delete .CUP files"), _("Error"),
                    MB_OK | MB_ICONEXCLAMATION);
     return;
   }
 
-  const TCHAR *fname = task_store->GetName(cursor_index);
+  const TCHAR *fname = task_store.GetName(cursor_index);
 
   StaticString<1024> text;
   text.Format(_T("%s\n(%s)"), _("Delete the selected task?"), fname);
@@ -285,7 +256,7 @@ TaskListPanel::DeleteTask()
 
   File::Delete(path);
 
-  task_store->Scan(more);
+  task_store.Scan(more);
   RefreshView();
 }
 
@@ -309,10 +280,10 @@ void
 TaskListPanel::RenameTask()
 {
   const unsigned cursor_index = GetList().GetCursorIndex();
-  if (cursor_index >= task_store->Size())
+  if (cursor_index >= task_store.Size())
     return;
 
-  const TCHAR *oldname = task_store->GetName(cursor_index);
+  const TCHAR *oldname = task_store.GetName(cursor_index);
   StaticString<40> newname(oldname);
 
   if (ClearSuffix(newname.buffer(), _T(".cup"))) {
@@ -328,12 +299,12 @@ TaskListPanel::RenameTask()
 
   newname.append(_T(".tsk"));
 
-  TCHAR buffer[MAX_PATH];
-  Directory::Create(LocalPath(buffer, _T("tasks")));
-  File::Rename(task_store->GetPath(cursor_index),
-               LocalPath(buffer, _T("tasks"), newname.c_str()));
+  const auto tasks_path = MakeLocalPath(_T("tasks"));
 
-  task_store->Scan(more);
+  File::Rename(task_store.GetPath(cursor_index),
+               AllocatedPath::Build(tasks_path, newname));
+
+  task_store.Scan(more);
   RefreshView();
 }
 
@@ -344,39 +315,32 @@ TaskListPanel::OnMoreClicked()
 
   more_button->SetCaption(more ? _("Less") : _("More"));
 
-  task_store->Scan(more);
+  task_store.Scan(more);
   RefreshView();
 }
 
 void
-TaskListPanel::Prepare(ContainerWindow &parent, const PixelRect &rc)
+TaskListPanel::Prepare(ContainerWindow &parent, const PixelRect &rc) noexcept
 {
-  CreateList(parent, dialog.GetLook(),
-             rc, Layout::GetMinimumControlHeight());
+  const DialogLook &look = UIGlobals::GetDialogLook();
+
+  CreateList(parent, dialog.GetLook(), rc,
+             row_renderer.CalculateLayout(*look.list.font));
 
   CreateButtons(buttons->GetButtonPanel());
 
-  task_store = new TaskStore();
-
   /* mark the new TaskStore as "dirty" until the data directory really
      gets scanned */
   serial = task_list_serial - 1;
 }
 
 void
-TaskListPanel::Unprepare()
-{
-  delete task_store;
-  DeleteWindow();
-}
-
-void
-TaskListPanel::Show(const PixelRect &rc)
+TaskListPanel::Show(const PixelRect &rc) noexcept
 {
   if (serial != task_list_serial) {
     serial = task_list_serial;
     // Scan XCSoarData for available tasks
-    task_store->Scan(more);
+    task_store.Scan(more);
   }
 
   dialog.ShowTaskView(get_cursor_task());
@@ -387,26 +351,31 @@ TaskListPanel::Show(const PixelRect &rc)
 }
 
 void
-TaskListPanel::Hide()
+TaskListPanel::Hide() noexcept
 {
   dialog.ResetTaskView();
 
   ListWidget::Hide();
 }
 
-Widget *
+std::unique_ptr<Widget>
 CreateTaskListPanel(TaskManagerDialog &dialog,
-                    OrderedTask **active_task, bool *task_modified)
+                    std::unique_ptr<OrderedTask> &active_task,
+                    bool *task_modified) noexcept
 {
-  TextWidget *summary = new TextWidget();
-  TaskListPanel *widget = new TaskListPanel(dialog, active_task, task_modified,
-                                            *summary);
-  TwoWidgets *tw = new TwoWidgets(widget, summary);
-  widget->SetTwoWidgets(*tw);
+  auto summary = std::make_unique<TextWidget>();
+  auto widget = std::make_unique<TaskListPanel>(dialog, active_task, task_modified,
+                                                *summary);
+  auto tw = std::make_unique<TwoWidgets>(std::move(widget),
+                                         std::move(summary));
+  auto &list = (TaskListPanel &)tw->GetFirst();
 
-  ButtonPanelWidget *buttons =
-    new ButtonPanelWidget(tw, ButtonPanelWidget::Alignment::BOTTOM);
-  widget->SetButtonPanel(*buttons);
+  list.SetTwoWidgets(*tw);
+
+  auto buttons =
+    std::make_unique<ButtonPanelWidget>(std::move(tw),
+                                        ButtonPanelWidget::Alignment::BOTTOM);
+  list.SetButtonPanel(*buttons);
 
   return buttons;
 }
