@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -30,25 +30,21 @@ Copyright_License {
 #include "Form/Frame.hpp"
 #include "Form/Button.hpp"
 #include "Form/CheckBox.hpp"
-#include "Widget/DockWindow.hpp"
+#include "Widget/ManagedWidget.hpp"
 #include "Widget/PanelWidget.hpp"
 #include "Screen/Layout.hpp"
-#include "Screen/Font.hpp"
+#include "ui/canvas/Font.hpp"
 #include "Components.hpp"
 #include "Units/Units.hpp"
 #include "Engine/Task/Ordered/OrderedTask.hpp"
-#include "Engine/Task/Ordered/Points/StartPoint.hpp"
-#include "Engine/Task/Ordered/Points/FinishPoint.hpp"
 #include "Engine/Task/Ordered/Points/ASTPoint.hpp"
-#include "Engine/Task/Ordered/Points/AATPoint.hpp"
 #include "Engine/Task/Factory/AbstractTaskFactory.hpp"
 #include "Task/ObservationZones/LineSectorZone.hpp"
 #include "Task/ObservationZones/CylinderZone.hpp"
-#include "Task/ObservationZones/AnnularSectorZone.hpp"
 #include "Task/ObservationZones/KeyholeZone.hpp"
 #include "Task/TypeStrings.hpp"
 #include "Gauge/TaskView.hpp"
-#include "Compiler.h"
+#include "util/Compiler.h"
 #include "UIGlobals.hpp"
 #include "Look/MapLook.hpp"
 #include "Look/DialogLook.hpp"
@@ -60,20 +56,12 @@ Copyright_License {
 #include "Widgets/KeyholeZoneEditWidget.hpp"
 
 #ifdef ENABLE_OPENGL
-#include "Screen/OpenGL/Scissor.hpp"
+#include "ui/canvas/opengl/Scissor.hpp"
 #endif
 
 class TaskPointWidget final
   : public NullWidget,
-    ObservationZoneEditWidget::Listener,
-    ActionListener {
-  enum Buttons {
-    PREVIOUS, NEXT,
-    DETAILS, REMOVE, RELOCATE,
-    CHANGE_TYPE,
-    OPTIONAL_STARTS,
-    SCORE_EXIT,
-  };
+    ObservationZoneEditWidget::Listener {
 
   struct Layout {
     PixelRect waypoint_panel;
@@ -103,7 +91,7 @@ class TaskPointWidget final
   WndFrame type_label;
   Button change_type;
   WndOwnerDrawFrame map;
-  DockWindow properties_dock;
+  ManagedWidget properties_widget{nullptr};
 
   Button optional_starts;
   CheckBoxControl score_exit;
@@ -123,8 +111,13 @@ public:
   }
 
   void CreateButtons() {
-    previous_button = dialog.AddSymbolButton(_T("<"), *this, PREVIOUS);
-    next_button = dialog.AddSymbolButton(_T(">"), *this, NEXT);
+    previous_button = dialog.AddSymbolButton(_T("<"), [this](){
+      OnPreviousClicked();
+    });
+
+    next_button = dialog.AddSymbolButton(_T(">"), [this](){
+      OnNextClicked();
+    });
   }
 
 private:
@@ -137,7 +130,7 @@ private:
     type_label.Move(layout.type_label);
     change_type.Move(layout.change_type);
     map.Move(layout.map);
-    properties_dock.Move(layout.properties);
+    properties_widget.Move(layout.properties);
     optional_starts.Move(layout.optional_starts);
     score_exit.Move(layout.score_exit);
   }
@@ -157,31 +150,28 @@ private:
 
 public:
   /* virtual methods from class Widget */
-  void Prepare(ContainerWindow &parent, const PixelRect &rc) override;
+  void Prepare(ContainerWindow &parent, const PixelRect &rc) noexcept override;
+  void Unprepare() noexcept override;
 
-  void Unprepare() override {
-    properties_dock.DeleteWidget();
-  }
-
-  bool Save(bool &changed) override {
+  bool Save(bool &changed) noexcept override {
     ReadValues();
     changed = task_modified;
     return true;
   }
 
-  void Show(const PixelRect &rc) override {
+  void Show(const PixelRect &rc) noexcept override {
     const Layout layout(rc, look);
     waypoint_panel.MoveAndShow(layout.waypoint_panel);
     tp_panel.MoveAndShow(layout.tp_panel);
     MoveChildren(layout);
   }
 
-  void Hide() override {
+  void Hide() noexcept override {
     waypoint_panel.Hide();
     tp_panel.Hide();
   }
 
-  void Move(const PixelRect &rc) override {
+  void Move(const PixelRect &rc) noexcept override {
     const Layout layout(rc, look);
     waypoint_panel.Move(layout.waypoint_panel);
     tp_panel.Move(layout.tp_panel);
@@ -190,10 +180,7 @@ public:
 
 private:
   /* virtual methods from class ObservationZoneEditWidget::Listener */
-  void OnModified(ObservationZoneEditWidget &widget) override;
-
-  /* virtual methods from class ActionListener */
-  void OnAction(int id) override;
+  void OnModified(ObservationZoneEditWidget &widget) noexcept override;
 };
 
 TaskPointWidget::Layout::Layout(PixelRect rc, const DialogLook &look)
@@ -210,8 +197,8 @@ TaskPointWidget::Layout::Layout(PixelRect rc, const DialogLook &look)
     + font_height + button_height;
 
   const PixelRect waypoint_rc(padding, padding,
-                              waypoint_panel.right - waypoint_panel.left - padding,
-                              waypoint_panel.bottom - waypoint_panel.top - padding);
+                              waypoint_panel.GetWidth() - padding,
+                              waypoint_panel.GetHeight() - padding);
 
   waypoint_name = waypoint_rc;
   waypoint_name.bottom = waypoint_name.top + font_height + 2 * padding;
@@ -232,15 +219,15 @@ TaskPointWidget::Layout::Layout(PixelRect rc, const DialogLook &look)
   tp_panel.bottom -= padding;
 
   const PixelRect tp_rc(padding, padding,
-                        tp_panel.right - tp_panel.left - padding,
-                        tp_panel.bottom - tp_panel.top - padding);
+                        tp_panel.GetWidth() - padding,
+                        tp_panel.GetHeight() - padding);
 
   PixelRect type_rc = tp_rc;
   type_rc.bottom = type_rc.top + button_height;
 
   type_label = change_type = type_rc;
   type_label.right = change_type.left = type_rc.right
-    - look.button.font->TextSize(_("Change Type")).cx - 3 * padding;
+    - look.button.font->TextSize(_("Change Type")).width - 3 * padding;
 
   PixelRect buttons_rc = tp_rc;
   buttons_rc.top = buttons_rc.bottom - button_height;
@@ -255,7 +242,7 @@ TaskPointWidget::Layout::Layout(PixelRect rc, const DialogLook &look)
 }
 
 void
-TaskPointWidget::Prepare(ContainerWindow &parent, const PixelRect &rc)
+TaskPointWidget::Prepare(ContainerWindow &parent, const PixelRect &rc) noexcept
 {
   const Layout layout(rc, look);
 
@@ -267,93 +254,62 @@ TaskPointWidget::Prepare(ContainerWindow &parent, const PixelRect &rc)
   WindowStyle button_style;
   button_style.TabStop();
 
-  WindowStyle dock_style;
-  dock_style.ControlParent();
-
   waypoint_panel.Create(parent, look, layout.waypoint_panel, panel_style);
   waypoint_name.Create(waypoint_panel, layout.waypoint_name);
   waypoint_details.Create(waypoint_panel, look.button, _("Details"),
                           layout.waypoint_details,
-                          button_style, *this, DETAILS);
+                          button_style, [this](){ OnDetailsClicked(); });
   waypoint_remove.Create(waypoint_panel, look.button, _("Remove"),
                          layout.waypoint_remove,
-                         button_style, *this, REMOVE);
+                         button_style, [this](){ OnRemoveClicked(); });
   waypoint_relocate.Create(waypoint_panel, look.button, _("Relocate"),
                            layout.waypoint_relocate,
-                           button_style, *this, RELOCATE);
+                           button_style, [this](){ OnRelocateClicked(); });
 
   tp_panel.Create(parent, look, layout.tp_panel, panel_style);
 
   type_label.Create(tp_panel, layout.type_label);
   change_type.Create(tp_panel, look.button, _("Change Type"),
                      layout.change_type,
-                     button_style, *this, CHANGE_TYPE);
+                     button_style, [this](){ OnTypeClicked(); });
   map.Create(tp_panel, layout.map, WindowStyle(),
              [this](Canvas &canvas, const PixelRect &rc){
                PaintMap(canvas, rc);
              });
-  properties_dock.Create(tp_panel, layout.properties, dock_style);
+
+  properties_widget.Initialise(tp_panel, layout.properties);
   optional_starts.Create(tp_panel, look.button, _("Enable Alternate Starts"),
                          layout.optional_starts, button_style,
-                         *this, OPTIONAL_STARTS);
+                         [this](){ OnOptionalStartsClicked(); });
   score_exit.Create(tp_panel, look, _("Score exit"),
-                    layout.score_exit, button_style,
-                    *this, SCORE_EXIT);
+                    layout.score_exit, button_style, {});
 
   RefreshView();
 }
 
 void
-TaskPointWidget::OnAction(int id)
+TaskPointWidget::Unprepare() noexcept
 {
-    switch (id) {
-    case PREVIOUS:
-      OnPreviousClicked();
-      break;
-
-    case NEXT:
-      OnNextClicked();
-      break;
-
-    case DETAILS:
-      OnDetailsClicked();
-      break;
-
-    case REMOVE:
-      OnRemoveClicked();
-      break;
-
-    case RELOCATE:
-      OnRelocateClicked();
-      break;
-
-    case CHANGE_TYPE:
-      OnTypeClicked();
-      break;
-
-    case OPTIONAL_STARTS:
-      OnOptionalStartsClicked();
-      break;
-    }
+  properties_widget.Clear();
 }
 
-static ObservationZoneEditWidget *
+static std::unique_ptr<ObservationZoneEditWidget>
 CreateObservationZoneEditWidget(ObservationZonePoint &oz, bool is_fai_general)
 {
   switch (oz.GetShape()) {
   case ObservationZone::Shape::SECTOR:
   case ObservationZone::Shape::ANNULAR_SECTOR:
   case ObservationZone::Shape::SYMMETRIC_QUADRANT:
-    return new SectorZoneEditWidget((SectorZone &)oz);
+    return std::make_unique<SectorZoneEditWidget>((SectorZone &)oz);
 
   case ObservationZone::Shape::LINE:
-    return new LineSectorZoneEditWidget((LineSectorZone &)oz, !is_fai_general);
+    return std::make_unique<LineSectorZoneEditWidget>((LineSectorZone &)oz, !is_fai_general);
 
   case ObservationZone::Shape::CYLINDER:
-    return new CylinderZoneEditWidget((CylinderZone &)oz, !is_fai_general);
+    return std::make_unique<CylinderZoneEditWidget>((CylinderZone &)oz, !is_fai_general);
 
   case ObservationZone::Shape::CUSTOM_KEYHOLE:
-    return new KeyholeZoneEditWidget((KeyholeZone &)oz);
+    return std::make_unique<KeyholeZoneEditWidget>((KeyholeZone &)oz);
 
   case ObservationZone::Shape::FAI_SECTOR:
   case ObservationZone::Shape::DAEC_KEYHOLE:
@@ -374,19 +330,21 @@ TaskPointWidget::RefreshView()
 
   OrderedTaskPoint &tp = ordered_task.GetPoint(active_index);
 
-  properties_dock.DeleteWidget();
+  properties_widget.Clear();
 
   ObservationZonePoint &oz = tp.GetObservationZone();
   const bool is_fai_general =
     ordered_task.GetFactoryType() == TaskFactoryType::FAI_GENERAL;
-  auto *properties_widget = CreateObservationZoneEditWidget(oz, is_fai_general);
-  if (properties_widget != nullptr) {
-    properties_widget->SetListener(this);
-    properties_dock.SetWidget(properties_widget);
+  auto new_properties_widget = CreateObservationZoneEditWidget(oz, is_fai_general);
+  if (new_properties_widget != nullptr) {
+    new_properties_widget->SetListener(this);
+    properties_widget.Set(std::move(new_properties_widget));
   } else
-    properties_dock.SetWidget(new PanelWidget());
+    properties_widget.Set(std::make_unique<PanelWidget>());
 
-  type_label.SetCaption(OrderedTaskPointName(ordered_task.GetFactory().GetType(tp)));
+  properties_widget.Show();
+
+  type_label.SetText(OrderedTaskPointName(ordered_task.GetFactory().GetType(tp)));
 
   previous_button->SetEnabled(active_index > 0);
   next_button->SetEnabled(active_index < (ordered_task.TaskSize() - 1));
@@ -441,7 +399,7 @@ TaskPointWidget::RefreshView()
     StaticString<100> buffer;
     buffer.Format(_T("%s %s"), name_prefix_buffer.c_str(),
                   tp.GetWaypoint().name.c_str());
-    waypoint_name.SetCaption(buffer);
+    waypoint_name.SetText(buffer);
   }
 }
 
@@ -462,7 +420,7 @@ TaskPointWidget::ReadValues()
     }
   }
 
-  return properties_dock.SaveWidget(task_modified);
+  return properties_widget.Save(task_modified);
 }
 
 void
@@ -481,7 +439,7 @@ TaskPointWidget::PaintMap(Canvas &canvas, const PixelRect &rc)
                  basic.location_available
                  ? basic.location : GeoPoint::Invalid(),
                  CommonInterface::GetMapSettings(),
-                 look.task, look.airspace,
+                 look.task, look.airspace, look.overlay,
                  terrain, &airspace_database);
 }
 
@@ -505,7 +463,7 @@ inline void
 TaskPointWidget::OnDetailsClicked()
 {
   const OrderedTaskPoint &task_point = ordered_task.GetPoint(active_index);
-  dlgWaypointDetailsShowModal(task_point.GetWaypoint(), false);
+  dlgWaypointDetailsShowModal(task_point.GetWaypointPtr(), false);
 }
 
 inline void
@@ -515,12 +473,11 @@ TaskPointWidget::OnRelocateClicked()
     ? ordered_task.GetPoint(active_index - 1).GetLocation()
     : CommonInterface::Basic().location;
 
-  const Waypoint *wp = ShowWaypointListDialog(gpBearing,
-                                              &ordered_task, active_index);
+  auto wp = ShowWaypointListDialog(gpBearing, &ordered_task, active_index);
   if (wp == nullptr)
     return;
 
-  ordered_task.GetFactory().Relocate(active_index, *wp);
+  ordered_task.GetFactory().Relocate(active_index, std::move(wp));
   ordered_task.ClearName();
   ordered_task.UpdateGeometry();
   task_modified = true;
@@ -574,7 +531,7 @@ TaskPointWidget::OnOptionalStartsClicked()
 }
 
 void
-TaskPointWidget::OnModified(ObservationZoneEditWidget &widget)
+TaskPointWidget::OnModified(ObservationZoneEditWidget &widget) noexcept
 {
   ReadValues();
   map.Invalidate();
@@ -586,15 +543,14 @@ dlgTaskPointShowModal(OrderedTask &task,
 {
   const DialogLook &look = UIGlobals::GetDialogLook();
 
-  WidgetDialog dialog(look);
+  TWidgetDialog<TaskPointWidget>
+    dialog(WidgetDialog::Full{}, UIGlobals::GetMainWindow(),
+           look, _("Waypoint"));
 
-  TaskPointWidget widget(dialog, task, index);
-  dialog.CreateFull(UIGlobals::GetMainWindow(), _("Waypoint"), &widget);
+  dialog.SetWidget(dialog, task, index);
   dialog.AddButton(_("Close"), mrOK);
-  widget.CreateButtons();
+  dialog.GetWidget().CreateButtons();
   dialog.ShowModal();
-  dialog.StealWidget();
 
-  bool task_modified = widget.IsModified();
-  return task_modified;
+  return dialog.GetWidget().IsModified();
 }
