@@ -2,7 +2,7 @@
   Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -29,7 +29,7 @@ ObservationZoneEditWidget::ObservationZoneEditWidget(ObservationZone &_oz)
    oz(_oz), listener(nullptr) {}
 
 void
-ObservationZoneEditWidget::OnModified(DataField &df)
+ObservationZoneEditWidget::OnModified(DataField &df) noexcept
 {
   if (listener != nullptr)
     listener->OnModified(*this);
