@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -30,7 +30,7 @@ Copyright_License {
 #include "Form/DataField/Listener.hpp"
 #include "UIGlobals.hpp"
 #include "Waypoint/Waypoint.hpp"
-#include "Interface.hpp"
+#include "FormatSettings.hpp"
 #include "Language/Language.hpp"
 
 class WaypointEditWidget final : public RowFormWidget, DataFieldListener {
@@ -47,7 +47,7 @@ class WaypointEditWidget final : public RowFormWidget, DataFieldListener {
   bool modified;
 
 public:
-  WaypointEditWidget(const DialogLook &look, Waypoint _value)
+  WaypointEditWidget(const DialogLook &look, const Waypoint &_value) noexcept
     :RowFormWidget(look), value(_value), modified(false) {}
 
   const Waypoint &GetValue() const {
@@ -56,11 +56,11 @@ public:
 
 private:
   /* virtual methods from Widget */
-  void Prepare(ContainerWindow &parent, const PixelRect &rc) override;
-  bool Save(bool &changed) override;
+  void Prepare(ContainerWindow &parent, const PixelRect &rc) noexcept override;
+  bool Save(bool &changed) noexcept override;
 
   /* virtual methods from DataFieldListener */
-  void OnModified(gcc_unused DataField &df) override {
+  void OnModified(gcc_unused DataField &df) noexcept override {
     modified = true;
   }
 };
@@ -74,7 +74,7 @@ static constexpr StaticEnumChoice waypoint_types[] = {
 
 void
 WaypointEditWidget::Prepare(gcc_unused ContainerWindow &parent,
-                            gcc_unused const PixelRect &rc)
+                            gcc_unused const PixelRect &rc) noexcept
 {
   AddText(_("Name"), nullptr, value.name.c_str(), this);
   AddText(_("Comment"), nullptr, value.comment.c_str(), this);
@@ -84,7 +84,7 @@ WaypointEditWidget::Prepare(gcc_unused ContainerWindow &parent,
                             this));
   AddFloat(_("Altitude"), nullptr,
            _T("%.0f %s"), _T("%.0f"),
-           fixed(0), fixed(30000), fixed(5), false,
+           0, 30000, 5, false,
            UnitGroup::ALTITUDE, value.elevation);
   AddEnum(_("Type"), nullptr, waypoint_types,
           value.IsAirport() ? 1u : (value.IsLandable() ? 2u : 0u),
@@ -92,7 +92,7 @@ WaypointEditWidget::Prepare(gcc_unused ContainerWindow &parent,
 }
 
 bool
-WaypointEditWidget::Save(bool &_changed)
+WaypointEditWidget::Save(bool &_changed) noexcept
 {
   bool changed = modified;
   value.name = GetValueString(NAME);
@@ -120,7 +120,7 @@ WaypointEditWidget::Save(bool &_changed)
   return true;
 }
 
-bool
+WaypointEditResult
 dlgWaypointEditShowModal(Waypoint &way_point)
 {
   if (UIGlobals::GetFormatSettings().coordinate_format ==
@@ -128,21 +128,24 @@ dlgWaypointEditShowModal(Waypoint &way_point)
     ShowMessageBox(
         _("Sorry, the waypoint editor is not yet available for the UTM coordinate format."),
         _("Waypoint Editor"), MB_OK);
-    return false;
+    return WaypointEditResult::CANCEL;
   }
 
   const DialogLook &look = UIGlobals::GetDialogLook();
-  WidgetDialog dialog(look);
-  WaypointEditWidget widget(look, way_point);
-  dialog.CreateAuto(UIGlobals::GetMainWindow(), _("Waypoint Editor"), &widget);
+  TWidgetDialog<WaypointEditWidget>
+    dialog(WidgetDialog::Auto{}, UIGlobals::GetMainWindow(),
+           look, _("Waypoint Editor"));
   dialog.AddButton(_("OK"), mrOK);
   dialog.AddButton(_("Cancel"), mrCancel);
+  dialog.SetWidget(look, way_point);
   const int result = dialog.ShowModal();
-  dialog.StealWidget();
 
-  if (result != mrOK || !dialog.GetChanged())
-    return false;
+  if (result != mrOK)
+    return WaypointEditResult::CANCEL;
 
-  way_point = widget.GetValue();
-  return true;
+  if (!dialog.GetChanged())
+    return WaypointEditResult::UNMODIFIED;
+
+  way_point = dialog.GetWidget().GetValue();
+  return WaypointEditResult::MODIFIED;
 }
