@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -21,7 +21,8 @@ Copyright_License {
 }
 */
 
-#include "WeatherDialogs.hpp"
+#include "NOAAList.hpp"
+#include "NOAADetails.hpp"
 #include "Dialogs/Message.hpp"
 #include "Dialogs/JobDialog.hpp"
 #include "Language/Language.hpp"
@@ -31,33 +32,23 @@ Copyright_License {
 
 #include "UIGlobals.hpp"
 #include "Look/DialogLook.hpp"
-#include "Dialogs/WidgetDialog.hpp"
 #include "Dialogs/TextEntry.hpp"
 #include "Form/Button.hpp"
+#include "Form/ButtonPanel.hpp"
 #include "Widget/ListWidget.hpp"
+#include "Widget/ButtonPanelWidget.hpp"
 #include "Weather/NOAAGlue.hpp"
 #include "Weather/NOAAStore.hpp"
 #include "Weather/NOAAUpdater.hpp"
-#include "Weather/METAR.hpp"
-#include "Util/TrivialArray.hpp"
-#include "Util/StringAPI.hxx"
-#include "Compiler.h"
+#include "net/http/Init.hpp"
+#include "util/TrivialArray.hxx"
+#include "util/StringAPI.hxx"
+#include "util/Compiler.h"
 #include "Renderer/NOAAListRenderer.hpp"
 #include "Renderer/TwoTextRowsRenderer.hpp"
 
-struct NOAAListItem
-{
-  StaticString<5> code;
-  NOAAStore::iterator iterator;
-
-  gcc_pure
-  bool operator<(const NOAAListItem &i2) const {
-    return StringCollate(code, i2.code) < 0;
-  }
-};
-
 class NOAAListWidget final
-  : public ListWidget, private ActionListener {
+  : public ListWidget {
   enum Buttons {
     DETAILS,
     ADD,
@@ -65,14 +56,30 @@ class NOAAListWidget final
     REMOVE,
   };
 
+  ButtonPanelWidget *buttons_widget;
+
   Button *details_button, *add_button, *update_button, *remove_button;
 
-  TrivialArray<NOAAListItem, 20> stations;
+  struct ListItem {
+    StaticString<5> code;
+    NOAAStore::iterator iterator;
+
+    gcc_pure
+    bool operator<(const ListItem &i2) const {
+      return StringCollate(code, i2.code) < 0;
+    }
+  };
+
+  TrivialArray<ListItem, 20> stations;
 
   TwoTextRowsRenderer row_renderer;
 
 public:
-  void CreateButtons(WidgetDialog &dialog);
+  void SetButtonPanel(ButtonPanelWidget &_buttons) {
+    buttons_widget = &_buttons;
+  }
+
+  void CreateButtons(ButtonPanel &buttons);
 
 private:
   void UpdateList();
@@ -85,39 +92,38 @@ private:
 
 public:
   /* virtual methods from class Widget */
-  virtual void Prepare(ContainerWindow &parent,
-                       const PixelRect &rc) override;
-  virtual void Unprepare() override;
+  void Prepare(ContainerWindow &parent,
+               const PixelRect &rc) noexcept override;
 
 protected:
   /* virtual methods from ListItemRenderer */
-  virtual void OnPaintItem(Canvas &canvas, const PixelRect rc,
-                           unsigned idx) override;
+  void OnPaintItem(Canvas &canvas, const PixelRect rc,
+                   unsigned idx) noexcept override;
 
   /* virtual methods from ListCursorHandler */
-  virtual bool CanActivateItem(unsigned index) const override {
+  bool CanActivateItem(unsigned index) const noexcept override {
     return true;
   }
 
-  virtual void OnActivateItem(unsigned index) override;
-
-private:
-  /* virtual methods from class ActionListener */
-  virtual void OnAction(int id) override;
+  void OnActivateItem(unsigned index) noexcept override;
 };
 
 void
-NOAAListWidget::CreateButtons(WidgetDialog &dialog)
+NOAAListWidget::CreateButtons(ButtonPanel &buttons)
 {
-  details_button = dialog.AddButton(_("Details"), *this, DETAILS);
-  add_button = dialog.AddButton(_("Add"), *this, ADD);
-  update_button = dialog.AddButton(_("Update"), *this, UPDATE);
-  remove_button = dialog.AddButton(_("Remove"), *this, REMOVE);
+  details_button = buttons.Add(_("Details"), [this](){ DetailsClicked(); });
+  add_button = buttons.Add(_("Add"), [this](){ AddClicked(); });
+  update_button = buttons.Add(_("Update"), [this](){ UpdateClicked(); });
+  remove_button = buttons.Add(_("Remove"), [this](){ RemoveClicked(); });
+
+  buttons.EnableCursorSelection();
 }
 
 void
-NOAAListWidget::Prepare(ContainerWindow &parent, const PixelRect &rc)
+NOAAListWidget::Prepare(ContainerWindow &parent, const PixelRect &rc) noexcept
 {
+  CreateButtons(buttons_widget->GetButtonPanel());
+
   const DialogLook &look = UIGlobals::GetDialogLook();
   CreateList(parent, look, rc,
              row_renderer.CalculateLayout(*look.list.font_bold,
@@ -125,19 +131,13 @@ NOAAListWidget::Prepare(ContainerWindow &parent, const PixelRect &rc)
   UpdateList();
 }
 
-void
-NOAAListWidget::Unprepare()
-{
-  DeleteWindow();
-}
-
 void
 NOAAListWidget::UpdateList()
 {
   stations.clear();
 
   for (auto i = noaa_store->begin(), end = noaa_store->end(); i != end; ++i) {
-    NOAAListItem item;
+    ListItem item;
     item.code = i->GetCodeT();
     item.iterator = i;
     stations.push_back(item);
@@ -157,7 +157,8 @@ NOAAListWidget::UpdateList()
 }
 
 void
-NOAAListWidget::OnPaintItem(Canvas &canvas, const PixelRect rc, unsigned index)
+NOAAListWidget::OnPaintItem(Canvas &canvas, const PixelRect rc,
+                            unsigned index) noexcept
 {
   assert(index < stations.size());
 
@@ -191,7 +192,7 @@ NOAAListWidget::AddClicked()
                          UIGlobals::GetDialogLook(),
                          _("Download"), true);
 
-  NOAAUpdater::Update(*i, runner);
+  NOAAUpdater::Update(*i, *Net::curl, runner);
 
   UpdateList();
 }
@@ -202,7 +203,7 @@ NOAAListWidget::UpdateClicked()
   DialogJobRunner runner(UIGlobals::GetMainWindow(),
                          UIGlobals::GetDialogLook(),
                          _("Download"), true);
-  NOAAUpdater::Update(*noaa_store, runner);
+  NOAAUpdater::Update(*noaa_store, *Net::curl, runner);
   UpdateList();
 }
 
@@ -241,52 +242,19 @@ NOAAListWidget::DetailsClicked()
 }
 
 void
-NOAAListWidget::OnActivateItem(unsigned index)
+NOAAListWidget::OnActivateItem(unsigned index) noexcept
 {
   OpenDetails(index);
 }
 
-void
-NOAAListWidget::OnAction(int id)
+std::unique_ptr<Widget>
+CreateNOAAListWidget()
 {
-  switch ((Buttons)id) {
-  case DETAILS:
-    DetailsClicked();
-    break;
-
-  case ADD:
-    AddClicked();
-    break;
-
-  case UPDATE:
-    UpdateClicked();
-    break;
-
-  case REMOVE:
-    RemoveClicked();
-    break;
-  }
+  auto buttons =
+    std::make_unique<ButtonPanelWidget>(std::make_unique<NOAAListWidget>(),
+                                        ButtonPanelWidget::Alignment::BOTTOM);
+  ((NOAAListWidget &)buttons->GetWidget()).SetButtonPanel(*buttons);
+  return buttons;
 }
 
-void
-dlgNOAAListShowModal()
-{
-  NOAAListWidget widget;
-  WidgetDialog dialog(UIGlobals::GetDialogLook());
-  dialog.CreateFull(UIGlobals::GetMainWindow(), _("METAR and TAF"), &widget);
-  dialog.AddButton(_("Close"), mrOK);
-  widget.CreateButtons(dialog);
-  dialog.EnableCursorSelection();
-
-  dialog.ShowModal();
-  dialog.StealWidget();
-}
-
-#else
-void
-dlgNOAAListShowModal()
-{
-  ShowMessageBox(_("This function is not available on your platform yet."),
-              _("Error"), MB_OK);
-}
 #endif
