@@ -1,7 +1,7 @@
 /* Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -26,8 +26,8 @@
 bool
 AirspacePredicateHeightRange::operator()(const AbstractAirspace& t) const
 {
-  return RoughAltitude(t.GetTop().altitude) >= h_min &&
-    RoughAltitude(t.GetBase().altitude) <= h_max;
+  return t.GetTop().altitude >= h_min &&
+    t.GetBase().altitude <= h_max;
 }
 
 bool
