@@ -1,7 +1,7 @@
 /* Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -24,7 +24,6 @@
 #define XCSOAR_OUTSIDE_AIRSPACE_PREDICATE_HPP
 
 #include "Geo/GeoPoint.hpp"
-#include "Compiler.h"
 
 class AbstractAirspace;
 
@@ -38,7 +37,7 @@ public:
   constexpr OutsideAirspacePredicate(const AGeoPoint &_location)
     :location(_location) {}
 
-  gcc_pure
+  [[gnu::pure]]
   bool operator()(const AbstractAirspace &airspace) const;
 };
 
