@@ -1,7 +1,7 @@
 /* Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -22,5 +22,5 @@
 
 #include "DMStQuad.hpp"
 
-DMStQuad::DMStQuad(const Trace &_trace)
+DMStQuad::DMStQuad(const Trace &_trace) noexcept
   :ContestDijkstra(_trace, true, 4, 1000) {}
