@@ -1,7 +1,7 @@
 /* Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -28,7 +28,7 @@ RoutePlannerConfig::SetDefaults()
   mode = Mode::NONE; // default disable while experimental
   allow_climb = true;
   use_ceiling = false;
-  safety_height_terrain = fixed(150);
+  safety_height_terrain = 150;
   reach_calc_mode = ReachMode::STRAIGHT;
   reach_polar_mode = Polar::SAFETY;
 }
