@@ -25,7 +25,7 @@
 void
 OrderedTaskSettings::SetDefaults()
 {
-  aat_min_time = 3600 * 3;
+  aat_min_time = std::chrono::hours{3};
   start_constraints.SetDefaults();
   finish_constraints.SetDefaults();
   fai_triangle.SetDefaults();
