@@ -57,18 +57,18 @@ AircraftStateFilter::Update(const AircraftState &state) noexcept
 {
   auto dt = state.time - last_state.time;
 
-  if (dt < 0 || dt > 60) {
+  if (dt.count() < 0 || dt > std::chrono::minutes{1}) {
     Reset(state);
     return;
   }
 
-  if (dt <= 0)
+  if (dt.count() <= 0)
     return;
 
   GeoVector vec(last_state.location, state.location);
 
   constexpr double MACH_1 = 343;
-  if (vec.distance > 1000 || vec.distance / dt > MACH_1) {
+  if (vec.distance > 1000 || vec.distance / dt.count() > MACH_1) {
     Reset(state);
     return;
   }
@@ -96,24 +96,24 @@ AircraftStateFilter::GetBearing() const noexcept
 }
 
 bool
-AircraftStateFilter::Design(const double cutoff_wavelength) noexcept
+AircraftStateFilter::Design(const FloatDuration cutoff_wavelength) noexcept
 {
   bool ok = true;
-  ok &= x_low_pass.Design(cutoff_wavelength);
-  ok &= y_low_pass.Design(cutoff_wavelength);
-  ok &= alt_low_pass.Design(cutoff_wavelength);
+  ok &= x_low_pass.Design(cutoff_wavelength.count());
+  ok &= y_low_pass.Design(cutoff_wavelength.count());
+  ok &= alt_low_pass.Design(cutoff_wavelength.count());
   assert(ok);
   return ok;
 }
 
 AircraftState
-AircraftStateFilter::GetPredictedState(const double in_time) const noexcept
+AircraftStateFilter::GetPredictedState(const FloatDuration in_time) const noexcept
 {
   AircraftState state_next = last_state;
   state_next.ground_speed = GetSpeed();
   state_next.vario = GetClimbRate();
-  state_next.altitude = last_state.altitude + state_next.vario * in_time;
-  state_next.location = GeoVector(state_next.ground_speed * in_time,
+  state_next.altitude = last_state.altitude + state_next.vario * in_time.count();
+  state_next.location = GeoVector(state_next.ground_speed * in_time.count(),
                                   GetBearing()).EndPoint(last_state.location);
   return state_next;
 }
