@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -33,11 +33,11 @@ Copyright_License {
 class PasswordDataField final : public DataFieldString {
 public:
   PasswordDataField(const TCHAR *initial_value,
-                    DataFieldListener *listener=nullptr)
+                    DataFieldListener *listener=nullptr) noexcept
     :DataFieldString(initial_value, listener) {}
 
   /* virtual methods from class DataField */
-  const TCHAR *GetAsDisplayString() const override;
+  const TCHAR *GetAsDisplayString() const noexcept override;
 };
 
 #endif
