@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -25,7 +25,7 @@ Copyright_License {
 #define XCSOAR_BYTE_SIZE_FORMATTER_HPP
 
 #include <tchar.h>
-#include <stddef.h>
+#include <cstddef>
 
 void FormatByteSize(TCHAR *buffer, size_t size,
                     unsigned long bytes, bool simple = false);
