@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -22,9 +22,9 @@ Copyright_License {
 */
 
 #include "InputKeys.hpp"
-#include "Screen/Key.h"
-#include "Util/CharUtil.hpp"
-#include "Util/StringAPI.hxx"
+#include "ui/event/KeyCode.hpp"
+#include "util/CharUtil.hxx"
+#include "util/StringAPI.hxx"
 
 struct string_to_key {
   const TCHAR *name;
@@ -50,7 +50,25 @@ static constexpr struct string_to_key string_to_key[] = {
   { _T("F10"), KEY_F10 },
   { _T("F11"), KEY_F11 },
   { _T("F12"), KEY_F12 },
-#ifdef USE_GDI
+
+#ifdef ANDROID
+  /* These keys are used by BlueTooth keypads and available in Android*/
+  { _T("BUTTON_R1"), KEYCODE_BUTTON_R1},
+  { _T("BUTTON_R2"), KEYCODE_BUTTON_R2},
+  { _T("BUTTON_L1"), KEYCODE_BUTTON_L1},
+  { _T("BUTTON_L2"), KEYCODE_BUTTON_L2},
+  { _T("BUTTON_A"), KEYCODE_BUTTON_A},
+  { _T("BUTTON_B"), KEYCODE_BUTTON_B},
+  { _T("BUTTON_C"), KEYCODE_BUTTON_C},
+  { _T("BUTTON_X"), KEYCODE_BUTTON_X},
+  { _T("BUTTON_Y"), KEYCODE_BUTTON_Y},
+  { _T("BUTTON_Z"), KEYCODE_BUTTON_Z},
+  { _T("MEDIA_NEXT"), KEYCODE_MEDIA_NEXT},
+  { _T("MEDIA_PREVIOUS"), KEYCODE_MEDIA_PREVIOUS},
+  { _T("MEDIA_PLAY_PAUSE"), KEYCODE_MEDIA_PLAY_PAUSE},
+#endif
+
+#ifdef USE_WINUSER
   /* These Keys are used for the Triadis-RemoteStick, as well as for
      expanded Keyboard-Events */
   { _T("F13"), KEY_F13 },
@@ -69,6 +87,7 @@ static constexpr struct string_to_key string_to_key[] = {
   { _T("RETURN"), KEY_RETURN },
   { _T("ESCAPE"), KEY_ESCAPE },
   { _T("MENU"), KEY_MENU },
+  { _T("TAB"), KEY_TAB },
   { NULL }
 };
 
