@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -29,11 +29,9 @@ HorizonLook::Initialise()
 {
   aircraft_pen.Create(Layout::Scale(2), COLOR_BLACK);
 
-  sky_color = Color(0x0a, 0xb9, 0xf3);
   sky_brush.Create(sky_color);
   sky_pen.Create(Layout::Scale(1), DarkColor(sky_color));
 
-  terrain_color = Color(0x80, 0x45, 0x15);
   terrain_brush.Create(terrain_color);
   terrain_pen.Create(Layout::Scale(1), DarkColor(terrain_color));
 }
