@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -24,17 +24,17 @@ Copyright_License {
 #ifndef HORIZON_LOOK_HPP
 #define HORIZON_LOOK_HPP
 
-#include "Screen/Pen.hpp"
-#include "Screen/Brush.hpp"
+#include "ui/canvas/Pen.hpp"
+#include "ui/canvas/Brush.hpp"
 
 struct HorizonLook {
   Pen aircraft_pen;
 
-  Color sky_color;
+  static constexpr Color sky_color{0x0a, 0xb9, 0xf3};
   Brush sky_brush;
   Pen sky_pen;
 
-  Color terrain_color;
+  static constexpr Color terrain_color{0x80, 0x45, 0x15};
   Brush terrain_brush;
   Pen terrain_pen;
 
