@@ -2,7 +2,7 @@
   Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -24,22 +24,31 @@
 #ifndef XCSOAR_TRAFFIC_LOOK_HPP
 #define XCSOAR_TRAFFIC_LOOK_HPP
 
-#include "Screen/Color.hpp"
-#include "Screen/Pen.hpp"
-#include "Screen/Brush.hpp"
-#include "Screen/Icon.hpp"
+#include "ui/canvas/Color.hpp"
+#include "ui/canvas/Pen.hpp"
+#include "ui/canvas/Brush.hpp"
+#include "ui/canvas/Icon.hpp"
 
 class Font;
 
 struct TrafficLook {
-  Color safe_color;
-  Color warning_color;
-  Color alarm_color;
+  static constexpr Color safe_above_color{0x1d,0x9b,0xc5};
+  static constexpr Color safe_below_color{0x1d,0xc5,0x10};
+  static constexpr Color warning_color{0xfe,0x84,0x38};
+  static constexpr Color warning_in_altitude_range_color{0xff,0x00,0xff};
+  static constexpr Color alarm_color{0xfb,0x35,0x2f};
 
-  Brush safe_brush;
+  Brush safe_above_brush;
+  Brush safe_below_brush;
   Brush warning_brush;
+  Brush warning_in_altitude_range_brush;
   Brush alarm_brush;
 
+  static constexpr Color team_color_green = Color(0x74, 0xff, 0);
+  static constexpr Color team_color_magenta = Color(0xff, 0, 0xcb);
+  static constexpr Color team_color_blue = Color(0, 0x90, 0xff);
+  static constexpr Color team_color_yellow = Color(0xff, 0xe8, 0);
+
   Pen team_pen_green;
   Pen team_pen_blue;
   Pen team_pen_yellow;
