@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -22,67 +22,49 @@ Copyright_License {
 */
 
 #include "Angle.hpp"
-#include <assert.h>
 
-void
-Angle::ToDMS(unsigned &dd, unsigned &mm, unsigned &ss, bool &is_positive) const
+#include <cassert>
+
+Angle::DMS
+Angle::ToDMS() const
 {
-  is_positive = !negative(value);
+  DMS dms;
+  dms.negative = value < 0;
 
-  unsigned value = uround(AbsoluteDegrees() * 3600);
+  unsigned value = lround(AbsoluteDegrees() * 3600);
 
-  ss = value % 60;
+  dms.seconds = value % 60;
   value /= 60;
 
-  mm = value % 60;
+  dms.minutes = value % 60;
   value /= 60;
 
-  dd = value;
+  dms.degrees = value;
+
+  return dms;
 }
 
 void
 Angle::ToDMM(unsigned &dd, unsigned &mm, unsigned &mmm,
              bool &is_positive) const
 {
-  is_positive = !negative(value);
+  is_positive = value >= 0;
 
-  unsigned value = (unsigned) (AbsoluteDegrees() * 60000);
+  unsigned value = lround(AbsoluteDegrees() * 60000);
   dd = value / 60000;
   value %= 60000;
   mm = value / 1000;
   mmm = value % 1000;
 }
 
-int
-Angle::Sign(const fixed tolerance) const
-{
-  if ((value > tolerance))
-    return 1;
-  if ((value < -tolerance))
-    return -1;
-
-  return 0;
-}
-
-int
-Angle::Sign() const
-{
-  if (positive(value))
-    return 1;
-  if (negative(value))
-    return -1;
-
-  return 0;
-}
-
-fixed
-Angle::AbsoluteDegrees() const 
+double
+Angle::AbsoluteDegrees() const
 {
   return Absolute().Degrees();
 }
 
-fixed
-Angle::AbsoluteRadians() const 
+double
+Angle::AbsoluteRadians() const
 {
   return Absolute().Radians();
 }
@@ -92,7 +74,7 @@ Angle::AsBearing() const
 {
   assert(!isnan(value));
   assert(!isinf(value));
-  assert(fabs(value) < fixed(100) * FullCircle().Native());
+  assert(fabs(value) < 100 * FullCircle().Native());
 
 #ifndef FIXED_MATH
   /* Workaround for endless loops below; this is only for release
@@ -120,7 +102,7 @@ Angle::AsDelta() const
 {
   assert(!isnan(value));
   assert(!isinf(value));
-  assert(fabs(value) < fixed(100) * FullCircle().Native());
+  assert(fabs(value) < 100 * FullCircle().Native());
 
 #ifndef FIXED_MATH
   /* same workaround as in AsBearing() */
@@ -164,7 +146,7 @@ Angle::HalfAngle(const Angle end) const
 }
 
 Angle
-Angle::Fraction(const Angle end, const fixed fraction) const
+Angle::Fraction(const Angle end, const double fraction) const
 {
   if (value == end.value)
     return Angle(value);
@@ -173,7 +155,6 @@ Angle::Fraction(const Angle end, const fixed fraction) const
   return Angle(value + diff.value * fraction);
 }
 
-gcc_pure
 bool
 Angle::Between(const Angle start, const Angle end) const
 {
