@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -25,32 +25,32 @@ Copyright_License {
 #include "ProgressGlue.hpp"
 
 void
-VerboseOperationEnvironment::SetText(const TCHAR *text)
+VerboseOperationEnvironment::SetText(const TCHAR *text) noexcept
 {
   ProgressGlue::Create(text);
 }
 
 void
-VerboseOperationEnvironment::SetProgressRange(unsigned range)
+VerboseOperationEnvironment::SetProgressRange(unsigned range) noexcept
 {
   ProgressGlue::SetRange(range);
 }
 
 void
-VerboseOperationEnvironment::SetProgressPosition(unsigned position)
+VerboseOperationEnvironment::SetProgressPosition(unsigned position) noexcept
 {
   ProgressGlue::SetValue(position);
 }
 
 void
-VerboseOperationEnvironment::UpdateLayout()
+VerboseOperationEnvironment::UpdateLayout() noexcept
 {
   ProgressGlue::Close();
   ProgressGlue::Create(nullptr);
 }
 
 void
-VerboseOperationEnvironment::Hide()
+VerboseOperationEnvironment::Hide() noexcept
 {
   ProgressGlue::Close();
 }
