@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -24,9 +24,8 @@ Copyright_License {
 #ifndef PLANE_HPP
 #define PLANE_HPP
 
-#include "Util/StaticString.hxx"
+#include "util/StaticString.hxx"
 #include "Polar/Shape.hpp"
-#include "Math/fixed.hpp"
 
 struct Plane
 {
@@ -38,11 +37,11 @@ struct Plane
 
   PolarShape polar_shape;
 
-  fixed reference_mass;
-  fixed dry_mass;
-  fixed max_ballast;
-  fixed max_speed;
-  fixed wing_area;
+  double reference_mass;
+  double dry_mass;
+  double max_ballast;
+  double max_speed;
+  double wing_area;
 
   /** Time to drain full ballast (s) */
   unsigned dump_time;
