@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -32,8 +32,4 @@ Profile::Load(const ProfileMap &map, SystemSettings &settings)
 {
   for (unsigned i = 0; i < settings.devices.size(); ++i)
     GetDeviceConfig(map, i, settings.devices[i]);
-
-#ifdef HAVE_MODEL_TYPE
-  map.GetEnum(ProfileKeys::AppInfoBoxModel, settings.model_type);
-#endif
 }
