@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -25,7 +25,6 @@ Copyright_License {
 #define XCSOAR_BITMAP_BUTTON_RENDERER_HPP
 
 #include "ButtonRenderer.hpp"
-#include "Compiler.h"
 
 class Bitmap;
 
@@ -39,7 +38,7 @@ public:
   explicit BitmapButtonRenderer(const Bitmap &_bitmap)
     :bitmap(_bitmap) {}
 
-  gcc_pure
+  [[gnu::pure]]
   unsigned GetMinimumButtonWidth() const override;
 
   void DrawButton(Canvas &canvas, const PixelRect &rc,
