@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -24,7 +24,7 @@ Copyright_License {
 #ifndef XCSOAR_LABEL_SHAPE_HPP
 #define XCSOAR_LABEL_SHAPE_HPP
 
-#include <stdint.h>
+#include <cstdint>
 
 enum class LabelShape : uint8_t {
   SIMPLE,
