@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -22,8 +22,8 @@ Copyright_License {
 */
 
 #include "UnitSymbolRenderer.hpp"
-#include "Screen/Canvas.hpp"
-#include "Util/Macros.hpp"
+#include "ui/canvas/Canvas.hpp"
+#include "util/Macros.hpp"
 
 #include <algorithm>
 
@@ -60,19 +60,40 @@ static constexpr UnitSymbolStrings symbol_strings[] = {
   { _T("lb"), _T("ft²"), true },
   { nullptr, _T("kg"), false },
   { nullptr, _T("lb"), false },
+  { _T("%"), _T(" "), false },
+  { nullptr, _T(":1"), false },
+  { nullptr, _T("V"), false },
 };
 
 static_assert(ARRAY_SIZE(symbol_strings) == (size_t)Unit::COUNT,
               "number of unit symbols does not match number of units");
 
 PixelSize
-UnitSymbolRenderer::GetSize(const Canvas &canvas, const Unit unit)
+UnitSymbolRenderer::GetSize(const Font &font, const Unit unit) noexcept
 {
   assert((size_t)unit < ARRAY_SIZE(symbol_strings));
 
-  if (unit == Unit::UNDEFINED)
+  const UnitSymbolStrings &strings = symbol_strings[(unsigned)unit];
+
+  if (!strings.line1 && !strings.line2)
     return {0, 0};
 
+  assert(strings.line2 != nullptr);
+
+  if (!strings.line1)
+    return font.TextSize(strings.line2);
+
+  PixelSize size1 = font.TextSize(strings.line1);
+  PixelSize size2 = font.TextSize(strings.line2);
+
+  return {std::max(size1.width, size2.width), size1.height + size2.height};
+}
+
+PixelSize
+UnitSymbolRenderer::GetSize(const Canvas &canvas, const Unit unit) noexcept
+{
+  assert((size_t)unit < ARRAY_SIZE(symbol_strings));
+
   const UnitSymbolStrings &strings = symbol_strings[(unsigned)unit];
 
   if (!strings.line1 && !strings.line2)
@@ -86,21 +107,14 @@ UnitSymbolRenderer::GetSize(const Canvas &canvas, const Unit unit)
   PixelSize size1 = canvas.CalcTextSize(strings.line1);
   PixelSize size2 = canvas.CalcTextSize(strings.line2);
 
-  PixelSize size;
-  size.cy = size1.cy + size2.cy;
-  size.cx = std::max(size1.cx, size2.cx);
-
-  return size;
+  return {std::max(size1.width, size2.width), size1.height + size2.height};
 }
 
-UPixelScalar
-UnitSymbolRenderer::GetAscentHeight(const Font &font, const Unit unit)
+unsigned
+UnitSymbolRenderer::GetAscentHeight(const Font &font, const Unit unit) noexcept
 {
   assert((size_t)unit < ARRAY_SIZE(symbol_strings));
 
-  if (unit == Unit::UNDEFINED)
-    return 0;
-
   const UnitSymbolStrings &strings = symbol_strings[(unsigned)unit];
 
   if (!strings.line1 && !strings.line2)
@@ -115,14 +129,12 @@ UnitSymbolRenderer::GetAscentHeight(const Font &font, const Unit unit)
 }
 
 void
-UnitSymbolRenderer::Draw(Canvas &canvas, const RasterPoint pos,
-                         const Unit unit, const Pen &unit_fraction_pen)
+UnitSymbolRenderer::Draw(Canvas &canvas, const PixelPoint pos,
+                         const Unit unit,
+                         const Pen &unit_fraction_pen) noexcept
 {
   assert((size_t)unit < ARRAY_SIZE(symbol_strings));
 
-  if (unit == Unit::UNDEFINED)
-    return;
-
   const UnitSymbolStrings &strings = symbol_strings[(unsigned)unit];
 
   if (!strings.line1 && !strings.line2)
@@ -131,30 +143,32 @@ UnitSymbolRenderer::Draw(Canvas &canvas, const RasterPoint pos,
   assert(strings.line2 != nullptr);
 
   if (!strings.line1) {
-    canvas.DrawText(pos.x, pos.y, strings.line2);
+    canvas.DrawText(pos, strings.line2);
     return;
   }
 
   PixelSize size1 = canvas.CalcTextSize(strings.line1);
   PixelSize size2 = canvas.CalcTextSize(strings.line2);
 
-  if (size1.cx > size2.cx) {
+  if (size1.width > size2.width) {
     if (strings.is_fraction) {
       canvas.Select(unit_fraction_pen);
-      canvas.DrawLine(pos.x, pos.y + size1.cy, pos.x + size1.cx, pos.y + size1.cy);
+      canvas.DrawLine(pos.At(0, size1.height),
+                      pos.At(size1.width, size1.height));
     }
 
-    canvas.DrawText(pos.x, pos.y, strings.line1);
-    PixelScalar x = pos.x + (size1.cx - size2.cx) / 2;
-    canvas.DrawText(x, pos.y + size1.cy, strings.line2);
+    canvas.DrawText(pos, strings.line1);
+    canvas.DrawText(pos.At((size1.width - size2.width) / 2,
+                           size1.height),
+                    strings.line2);
   } else {
     if (strings.is_fraction) {
       canvas.Select(unit_fraction_pen);
-      canvas.DrawLine(pos.x, pos.y + size1.cy, pos.x + size2.cx, pos.y + size1.cy);
+      canvas.DrawLine(pos.At(0, size1.height),
+                      pos.At(size2.width, size1.height));
     }
 
-    PixelScalar x = pos.x + (size2.cx - size1.cx) / 2;
-    canvas.DrawText(x, pos.y, strings.line1);
-    canvas.DrawText(pos.x, pos.y + size1.cy, strings.line2);
+    canvas.DrawText(pos.At((size2.width - size1.width) / 2, 0), strings.line1);
+    canvas.DrawText(pos.At(0, size1.height), strings.line2);
   }
 }
