@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -22,7 +22,10 @@ Copyright_License {
 */
 
 #include "Glue.hpp"
-#include "Net/HTTP/DownloadManager.hpp"
+#include "net/http/DownloadManager.hpp"
+#include "system/Path.hpp"
+
+#include <tchar.h>
 
 #define REPOSITORY_URI "http://download.xcsoar.org/repository"
 
@@ -35,5 +38,5 @@ EnqueueRepositoryDownload(bool force)
     return;
 
   repository_downloaded = true;
-  Net::DownloadManager::Enqueue(REPOSITORY_URI, _T("repository"));
+  Net::DownloadManager::Enqueue(REPOSITORY_URI, Path(_T("repository")));
 }
