@@ -54,10 +54,8 @@ MAKE_RESOURCE(IDB_OUTFIELD_REACHABLE, 291);
 MAKE_RESOURCE(IDB_OUTFIELD_REACHABLE_HD, 5291);
 MAKE_RESOURCE(IDB_OUTFIELD_UNREACHABLE, 292);
 MAKE_RESOURCE(IDB_OUTFIELD_UNREACHABLE_HD, 5292);
-MAKE_RESOURCE(IDB_VARIOSCALEA, 293);
 MAKE_RESOURCE(IDB_CLIMBSMALL, 313);
 MAKE_RESOURCE(IDB_CLIMBSMALLINV, 314);
-MAKE_RESOURCE(IDB_VARIOSCALEC, 315);
 MAKE_RESOURCE(IDB_THERMALSOURCE, 316);
 MAKE_RESOURCE(IDB_THERMALSOURCE_HD, 5316);
 MAKE_RESOURCE(IDB_TARGET, 320);
