@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -22,12 +22,10 @@ Copyright_License {
 */
 
 #include "StatusMessage.hpp"
-#include "Util/StringAPI.hxx"
-#include "Util/Macros.hpp"
+#include "util/StringAPI.hxx"
+#include "util/Macros.hpp"
 
-#include <assert.h>
-
-#include <assert.h>
+#include <cassert>
 
 static constexpr StatusMessage default_status_messages[] = {
 #include "Status_defaults.cpp"
