@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -24,7 +24,9 @@ Copyright_License {
 #ifndef XCSOAR_STATUS_MESSAGE_H
 #define XCSOAR_STATUS_MESSAGE_H
 
-#include "Compiler.h"
+#include "util/Compiler.h"
+
+#include <chrono>
 
 #include <tchar.h>
 
@@ -41,7 +43,7 @@ struct StatusMessage {
   bool visible;
 
   /** Delay for DoStatusMessage */
-  unsigned delay_ms;
+  std::chrono::steady_clock::duration delay;
 };
 
 gcc_pure
