@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -24,28 +24,26 @@ Copyright_License {
 #ifndef XCSOAR_TASK_TYPE_STRINGS_HPP
 #define XCSOAR_TASK_TYPE_STRINGS_HPP
 
-#include "Compiler.h"
-
 #include <tchar.h>
-#include <stdint.h>
+#include <cstdint>
 
 enum class TaskPointType : uint8_t;
 enum class TaskFactoryType : uint8_t;
 enum class TaskPointFactoryType : uint8_t;
 
-gcc_const
+[[gnu::const]]
 const TCHAR *
 OrderedTaskFactoryDescription(TaskFactoryType type);
 
-gcc_const
+[[gnu::const]]
 const TCHAR *
 OrderedTaskFactoryName(TaskFactoryType type);
 
-gcc_const
+[[gnu::const]]
 const TCHAR *
 OrderedTaskPointDescription(TaskPointFactoryType type);
 
-gcc_const
+[[gnu::const]]
 const TCHAR *
 OrderedTaskPointName(TaskPointFactoryType type);
 
