@@ -90,13 +90,13 @@
 typedef struct {
 
 	/* The C register. */
-	uint_fast32_t creg;
+	uint_least32_t creg;
 
 	/* The A register. */
-	uint_fast32_t areg;
+	uint_least32_t areg;
 
 	/* The CT register. */
-	uint_fast32_t ctreg;
+	uint_least32_t ctreg;
 
 	/* The current context. */
 	const jpc_mqstate_t **curctx;
@@ -105,7 +105,7 @@ typedef struct {
 	const jpc_mqstate_t **ctxs;
 
 	/* The maximum number of contexts. */
-	int maxctxs;
+	unsigned maxctxs;
 
 	/* The stream from which to read data. */
 	jas_stream_t *in;
@@ -114,7 +114,7 @@ typedef struct {
 	jas_uchar inbuffer;
 
 	/* The EOF indicator. */
-	int eof;
+	bool eof;
 
 } jpc_mqdec_t;
 
@@ -124,7 +124,7 @@ typedef struct {
 
 /* Create a MQ decoder. */
 gcc_malloc
-jpc_mqdec_t *jpc_mqdec_create(int maxctxs, jas_stream_t *in);
+jpc_mqdec_t *jpc_mqdec_create(unsigned maxctxs, jas_stream_t *in);
 
 /* Destroy a MQ decoder. */
 void jpc_mqdec_destroy(jpc_mqdec_t *dec);
@@ -144,14 +144,13 @@ void jpc_mqdec_init(jpc_mqdec_t *dec);
 \******************************************************************************/
 
 /* Set the current context for a MQ decoder. */
-#define	jpc_mqdec_setcurctx(dec, ctxno) \
-	((mqdec)->curctx = &(mqdec)->ctxs[ctxno]);
-
-/* Set the state information for a particular context of a MQ decoder. */
-void jpc_mqdec_setctx(jpc_mqdec_t *dec, int ctxno, const jpc_mqctx_t *ctx);
+static inline void jpc_mqdec_setcurctx(jpc_mqdec_t *dec, unsigned ctxno)
+{
+	dec->curctx = &dec->ctxs[ctxno];
+}
 
 /* Set the state information for all contexts of a MQ decoder. */
-void jpc_mqdec_setctxs(const jpc_mqdec_t *dec, int numctxs, const jpc_mqctx_t *ctxs);
+void jpc_mqdec_setctxs(const jpc_mqdec_t *dec, unsigned numctxs, const jpc_mqctx_t *ctxs);
 
 /******************************************************************************\
 * Functions/macros for decoding bits.
@@ -188,87 +187,58 @@ void jpc_mqdec_dump(const jpc_mqdec_t *dec, FILE *out);
 * GIVEN BELOW.
 \******************************************************************************/
 
-#define	jpc_mqdec_getbit_macro(dec) \
-	((((dec)->areg -= (*(dec)->curctx)->qeval), \
-	  (dec)->creg >> 16 >= (*(dec)->curctx)->qeval) ? \
-	  ((((dec)->creg -= (*(dec)->curctx)->qeval << 16), \
-	  (dec)->areg & 0x8000) ?  (*(dec)->curctx)->mps : \
-	  jpc_mqdec_mpsexchrenormd(dec)) : \
-	  jpc_mqdec_lpsexchrenormd(dec))
+bool jpc_mqdec_mpsexchrenormd(jpc_mqdec_t *dec);
+bool jpc_mqdec_lpsexchrenormd(jpc_mqdec_t *dec);
 
-#define	jpc_mqdec_mpsexchange(areg, delta, curctx, bit) \
-{ \
-	if ((areg) < (delta)) { \
-		register const jpc_mqstate_t *state = *(curctx); \
-		/* LPS decoded. */ \
-		(bit) = state->mps ^ 1; \
-		*(curctx) = state->nlps; \
-	} else { \
-		register const jpc_mqstate_t *state = *(curctx); \
-		/* MPS decoded. */ \
-		(bit) = state->mps; \
-		*(curctx) = state->nmps; \
-	} \
+JAS_FORCE_INLINE
+static bool jpc_mqdec_getbit_macro(jpc_mqdec_t *dec)
+{
+	const jpc_mqstate_t *const state = *dec->curctx;
+
+	dec->areg -= state->qeval;
+
+	if (dec->creg >= (uint_least32_t)state->qeval << 16) {
+		dec->creg -= (uint_least32_t)state->qeval << 16;
+		return dec->areg & 0x8000
+			? state->mps
+			: jpc_mqdec_mpsexchrenormd(dec);
+	} else {
+		return jpc_mqdec_lpsexchrenormd(dec);
+	}
 }
 
-#define	jpc_mqdec_lpsexchange(areg, delta, curctx, bit) \
-{ \
-	if ((areg) >= (delta)) { \
-		register const jpc_mqstate_t *state = *(curctx); \
-		(areg) = (delta); \
-		(bit) = state->mps ^ 1; \
-		*(curctx) = state->nlps; \
-	} else { \
-		register const jpc_mqstate_t *state = *(curctx); \
-		(areg) = (delta); \
-		(bit) = state->mps; \
-		*(curctx) = state->nmps; \
-	} \
+JAS_FORCE_INLINE
+static bool jpc_mqdec_mpsexchange(uint_least32_t areg, uint_least32_t delta, const jpc_mqstate_t **curctx)
+{
+	if (areg < delta) {
+		const jpc_mqstate_t *state = *curctx;
+		/* LPS decoded. */
+		*curctx = state->nlps;
+		return !state->mps;
+	} else {
+		const jpc_mqstate_t *state = *curctx;
+		/* MPS decoded. */
+		*curctx = state->nmps;
+		return state->mps;
+	}
 }
 
-#define	jpc_mqdec_renormd(areg, creg, ctreg, in, eof, inbuf) \
-{ \
-	do { \
-		if (!(ctreg)) { \
-			jpc_mqdec_bytein2(creg, ctreg, in, eof, inbuf); \
-		} \
-		(areg) <<= 1; \
-		(creg) <<= 1; \
-		--(ctreg); \
-	} while (!((areg) & 0x8000)); \
+JAS_FORCE_INLINE
+static bool jpc_mqdec_lpsexchange(uint_least32_t *areg_p, uint_least32_t delta, const jpc_mqstate_t **curctx)
+{
+	if (*areg_p >= delta) {
+		const jpc_mqstate_t *state = *curctx;
+		*areg_p = delta;
+		*curctx = state->nlps;
+		return !state->mps;
+	} else {
+		const jpc_mqstate_t *state = *curctx;
+		*areg_p = delta;
+		*curctx = state->nmps;
+		return state->mps;
+	}
 }
 
-#define	jpc_mqdec_bytein2(creg, ctreg, in, eof, inbuf) \
-{ \
-	int c; \
-	unsigned char prevbuf; \
-	if (!(eof)) { \
-		if ((c = jas_stream_getc(in)) == EOF) { \
-			(eof) = 1; \
-			c = 0xff; \
-		} \
-		prevbuf = (inbuf); \
-		(inbuf) = c; \
-		if (prevbuf == 0xff) { \
-			if (c > 0x8f) { \
-				(creg) += 0xff00; \
-				(ctreg) = 8; \
-			} else { \
-				(creg) += c << 9; \
-				(ctreg) = 7; \
-			} \
-		} else { \
-			(creg) += c << 8; \
-			(ctreg) = 8; \
-		} \
-	} else { \
-		(creg) += 0xff00; \
-		(ctreg) = 8; \
-	} \
-}
-
-int jpc_mqdec_getbit_func(jpc_mqdec_t *dec);
-int jpc_mqdec_mpsexchrenormd(jpc_mqdec_t *dec);
-int jpc_mqdec_lpsexchrenormd(jpc_mqdec_t *dec);
+bool jpc_mqdec_getbit_func(jpc_mqdec_t *dec);
 
 #endif
