@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -25,9 +25,9 @@ Copyright_License {
 #define XCSOAR_TRACKING_SKYLINES_QUEUE_HPP
 
 #include "Protocol.hpp"
-#include "Util/OverwritingRingBuffer.hpp"
+#include "util/OverwritingRingBuffer.hpp"
 
-#include <stdint.h>
+#include <cstdint>
 
 namespace SkyLinesTracking {
 
