@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -24,10 +24,11 @@ Copyright_License {
 #ifndef WAYPOINT_FILE_TYPE_HPP
 #define WAYPOINT_FILE_TYPE_HPP
 
-#include "Compiler.h"
+#include "util/Compiler.h"
 
-#include <stdint.h>
-#include <tchar.h>
+#include <cstdint>
+
+class Path;
 
 enum class WaypointFileType: uint8_t {
   UNKNOWN,
@@ -40,6 +41,7 @@ enum class WaypointFileType: uint8_t {
 };
 
 gcc_pure
-WaypointFileType DetermineWaypointFileType(const TCHAR *path);
+WaypointFileType
+DetermineWaypointFileType(Path path);
 
 #endif
