@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -25,11 +25,13 @@ Copyright_License {
 #define NOAA_FORMATTER_HPP
 
 #include "NOAAStore.hpp"
-#include "Util/tstring.hpp"
+#include "util/tstring.hpp"
 
-namespace NOAAFormatter
-{
-  void Format(const NOAAStore::Item &station, tstring &output);
-};
+namespace NOAAFormatter {
+
+void
+Format(const NOAAStore::Item &station, tstring &output);
+
+} // namespace NOAAFormatter
 
 #endif
