@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -22,29 +22,28 @@ Copyright_License {
 */
 
 #include "ActionWidget.hpp"
-#include "Form/ActionListener.hpp"
 
 bool
-ActionWidget::Click()
+ActionWidget::Click() noexcept
 {
-  listener.OnAction(id);
+  callback();
   return false;
 }
 
 void
-ActionWidget::ReClick()
+ActionWidget::ReClick() noexcept
 {
-  listener.OnAction(id);
+  callback();
 }
 
 #ifndef HAVE_CLIPPING
 void
-ActionWidget::Show(const PixelRect &rc)
+ActionWidget::Show(const PixelRect &rc) noexcept
 {
 }
 
 void
-ActionWidget::Hide()
+ActionWidget::Hide() noexcept
 {
 }
 #endif
