@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -22,22 +22,20 @@ Copyright_License {
 */
 
 #include "KeyboardWidget.hpp"
-#include "Look/ButtonLook.hpp"
 #include "Renderer/SymbolButtonRenderer.hpp"
-#include "Util/StringAPI.hxx"
-#include "Util/StringUtil.hpp"
-#include "Util/CharUtil.hpp"
-#include "Screen/Canvas.hpp"
+#include "util/StringAPI.hxx"
+#include "util/StringCompare.hxx"
+#include "util/CharUtil.hxx"
 #include "Screen/Layout.hpp"
 
-#include <assert.h>
+#include <cassert>
 #include <string.h>
 
 static constexpr TCHAR keyboard_letters[] =
   _T("1234567890ABCDEFGHIJKLMNOPQRSTUVWXYZ");
 
 void
-KeyboardWidget::Prepare(ContainerWindow &parent, const PixelRect &rc)
+KeyboardWidget::Prepare(ContainerWindow &parent, const PixelRect &rc) noexcept
 {
   PrepareSize(rc);
 
@@ -50,21 +48,21 @@ KeyboardWidget::Prepare(ContainerWindow &parent, const PixelRect &rc)
 
   AddButton(parent, _T("Space"), ' ');
   AddButton(parent, _T("."), '.');
-  AddButton(parent, _T(","), ',');
+  AddButton(parent, _T("@"), '@');
   AddButton(parent, _T("-"), '-');
 
   if (show_shift_button) {
     WindowStyle style;
     style.Hide();
     shift_button.Create(parent, { 0, 0, 16, 16 }, style,
-                        new SymbolButtonRenderer(look, _T("v")),
-                        *this, SHIFT);
+                        std::make_unique<SymbolButtonRenderer>(look, _T("v")),
+                        [this](){ OnShiftClicked(); });
   }
   UpdateShiftState();
 }
 
 void
-KeyboardWidget::Show(const PixelRect &rc)
+KeyboardWidget::Show(const PixelRect &rc) noexcept
 {
   OnResize(rc);
 
@@ -76,7 +74,7 @@ KeyboardWidget::Show(const PixelRect &rc)
 }
 
 void
-KeyboardWidget::Hide()
+KeyboardWidget::Hide() noexcept
 {
   for (unsigned i = 0; i < num_buttons; ++i)
     buttons[i].Hide();
@@ -86,7 +84,7 @@ KeyboardWidget::Hide()
 }
 
 void
-KeyboardWidget::Move(const PixelRect &rc)
+KeyboardWidget::Move(const PixelRect &rc) noexcept
 {
   OnResize(rc);
 }
@@ -175,7 +173,7 @@ KeyboardWidget::MoveButtons(const PixelRect &rc)
   MoveButtonsToRow(rc, _T("1234567890"), 0);
   MoveButtonsToRow(rc, _T("QWERTYUIOP"), 1);
   MoveButtonsToRow(rc, _T("ASDFGHJKL"), 2, button_width / 3);
-  MoveButtonsToRow(rc, _T("ZXCVBNM,."), 3, button_width);
+  MoveButtonsToRow(rc, _T("ZXCVBNM@."), 3, button_width);
 
   if (IsLandscape(rc)) {
     MoveButton(_T('-'),
@@ -205,8 +203,8 @@ void
 KeyboardWidget::PrepareSize(const PixelRect &rc)
 {
   const PixelSize new_size = rc.GetSize();
-  button_width = new_size.cx / 10;
-  button_height = new_size.cy / 5;
+  button_width = new_size.width / 10;
+  button_height = new_size.height / 5;
 }
 
 void
@@ -265,13 +263,3 @@ KeyboardWidget::OnShiftClicked()
   shift_state = !shift_state;
   UpdateShiftState();
 }
-
-void
-KeyboardWidget::OnAction(int id)
-{
-  switch (id) {
-  case SHIFT:
-    OnShiftClicked();
-    break;
-  }
-}
