@@ -24,6 +24,8 @@ Copyright_License {
 #ifndef XCSOAR_ROUGH_TIME_SPAN_HPP
 #define XCSOAR_ROUGH_TIME_SPAN_HPP
 
+#include "Stamp.hpp"
+
 #include <cassert>
 #include <chrono>
 #include <cstdint>
@@ -56,31 +58,48 @@ public:
   {
   }
 
-  [[gnu::const]]
-  static RoughTime FromMinuteOfDay(unsigned mod) noexcept {
+  static constexpr RoughTime FromMinuteOfDay(unsigned mod) noexcept {
     assert(std::chrono::minutes{mod} < MAX);
 
     return RoughTime(std::chrono::minutes{mod});
   }
 
-  [[gnu::const]]
-  static RoughTime FromMinuteOfDayChecked(int mod) noexcept {
+  /**
+   * Construct a #RoughTime object from the specified duration since
+   * midnight.
+   */
+  template<class Rep, class Period>
+  static constexpr RoughTime FromSinceMidnight(const std::chrono::duration<Rep,Period> &since_midnight) noexcept {
+    return FromMinuteOfDay(std::chrono::duration_cast<std::chrono::minutes>(since_midnight).count());
+  }
+
+  static constexpr RoughTime FromMinuteOfDayChecked(int mod) noexcept {
     while (mod < 0)
       mod += MAX.count();
 
     return FromMinuteOfDayChecked(unsigned(mod));
   }
 
-  [[gnu::const]]
-  static RoughTime FromMinuteOfDayChecked(unsigned mod) noexcept {
+  /**
+   * A wrapper for FromSinceMidnight() which allows values bigger than
+   * one day.
+   */
+  template<class Rep, class Period>
+  static constexpr RoughTime FromSinceMidnightChecked(const std::chrono::duration<Rep,Period> &since_midnight) noexcept {
+    return FromMinuteOfDayChecked((int)std::chrono::duration_cast<std::chrono::minutes>(since_midnight).count());
+  }
+
+  static constexpr RoughTime FromMinuteOfDayChecked(unsigned mod) noexcept {
     return RoughTime(std::chrono::minutes{mod % MAX.count()});
   }
 
-  [[gnu::const]]
-  static RoughTime FromSecondOfDayChecked(unsigned sod) noexcept {
+  static constexpr RoughTime FromSecondOfDayChecked(unsigned sod) noexcept {
     return FromMinuteOfDayChecked(sod / 60);
   }
 
+  explicit constexpr RoughTime(TimeStamp t) noexcept
+    :RoughTime(FromSinceMidnightChecked(t.ToDuration())) {}
+
   static constexpr RoughTime Invalid() noexcept {
     return RoughTime(INVALID);
   }
@@ -145,6 +164,10 @@ public:
     value = (value + MAX - Duration{1}) % MAX;
     return *this;
   }
+
+  constexpr operator TimeStamp() const noexcept {
+    return TimeStamp{value};
+  }
 };
 
 /**
@@ -235,6 +258,12 @@ public:
     return RoughTimeDelta(Duration{_value * 60});
   }
 
+  template<class Rep, class Period>
+  [[gnu::const]]
+  static RoughTimeDelta FromDuration(const std::chrono::duration<Rep,Period> &d) noexcept {
+    return RoughTimeDelta{std::chrono::duration_cast<Duration>(d)};
+  }
+
   constexpr std::chrono::minutes ToDuration() const noexcept {
     return value;
   }
@@ -260,8 +289,7 @@ public:
   }
 };
 
-[[gnu::const]]
-static inline RoughTime
+static constexpr RoughTime
 operator+(RoughTime t, RoughTimeDelta delta) noexcept
 {
   if (!t.IsValid())
@@ -271,8 +299,7 @@ operator+(RoughTime t, RoughTimeDelta delta) noexcept
   return RoughTime::FromMinuteOfDayChecked(value);
 }
 
-[[gnu::const]]
-static inline RoughTime
+static constexpr RoughTime
 operator-(RoughTime t, RoughTimeDelta delta) noexcept
 {
   return t + (-delta);
