@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -26,10 +26,13 @@ Copyright_License {
 #include "Device/Port/ConfiguredPort.hpp"
 #include "Device/Config.hpp"
 #include "DebugPort.hpp"
-#include "OS/Args.hpp"
+#include "system/Args.hpp"
 #include "Operation/ConsoleOperationEnvironment.hpp"
-#include "Util/Macros.hpp"
-#include "IO/Async/GlobalIOThread.hpp"
+#include "util/Macros.hpp"
+#include "util/PrintException.hxx"
+#include "io/async/GlobalAsioThread.hpp"
+#include "io/async/AsioThread.hpp"
+#include "io/NullDataHandler.hpp"
 
 #include <stdio.h>
 
@@ -147,13 +150,8 @@ RunCommand(CAI302Device &device, const char *command,
   }
 }
 
-#ifdef __clang__
-/* true, the nullptr cast below is a bad kludge */
-#pragma GCC diagnostic ignored "-Wnull-dereference"
-#endif
-
 int main(int argc, char **argv)
-{
+try {
   const char *const usage = "PORT BAUD COMMAND\n\n"
     "Where COMMAND is one of:"
     "\n\tinfo"
@@ -165,35 +163,30 @@ int main(int argc, char **argv)
     "\n\tnavpoints"
     ;
   Args args(argc, argv, usage);
-  const DeviceConfig config = ParsePortArgs(args);
-
+  DebugPort debug_port(args);
   const char *command = args.ExpectNext();
   args.ExpectEnd();
 
-  InitialiseIOThread();
+  ScopeGlobalAsioThread global_asio_thread;
 
-  Port *port = OpenPort(config, nullptr, *(DataHandler *)nullptr);
-  if (port == NULL) {
-    fprintf(stderr, "Failed to open port\n");
-    return EXIT_FAILURE;
-  }
+  NullDataHandler handler;
+  auto port = debug_port.Open(*asio_thread, *global_cares_channel, handler);
 
   ConsoleOperationEnvironment env;
 
   if (!port->WaitConnected(env)) {
-    delete port;
-    DeinitialiseIOThread();
     fprintf(stderr, "Failed to connect the port\n");
     return EXIT_FAILURE;
   }
 
-  CAI302Device device(config, *port);
+  CAI302Device device(debug_port.GetConfig(), *port);
   if (!RunCommand(device, command, env)) {
     fprintf(stderr, "error\n");
     return EXIT_FAILURE;
   }
 
-  delete port;
-  DeinitialiseIOThread();
   return EXIT_SUCCESS;
+} catch (const std::exception &exception) {
+  PrintException(exception);
+  return EXIT_FAILURE;
 }
