@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -30,9 +30,9 @@ Copyright_License {
 #include "Device/Util/NMEAWriter.hpp"
 #include "NMEA/InputLine.hpp"
 #include "NMEA/Checksum.hpp"
-#include "Util/Macros.hpp"
-#include "Util/StaticFifoBuffer.hpp"
-#include "Util/StaticString.hxx"
+#include "util/Macros.hpp"
+#include "util/StaticFifoBuffer.hxx"
+#include "util/StaticString.hxx"
 
 #include <string>
 #include <map>
@@ -133,8 +133,10 @@ private:
       FLARM::PrepareFrameHeader(sequence_number, FLARM::MT_ACK,
                                 &payload, sizeof(payload));
     return port->Write(FLARM::START_FRAME) &&
-      FLARM::SendEscaped(*port, &header, sizeof(header), *env, 2000) &&
-      FLARM::SendEscaped(*port, &payload, sizeof(payload), *env, 2000);
+      FLARM::SendEscaped(*port, &header, sizeof(header), *env,
+                         std::chrono::seconds(2)) &&
+      FLARM::SendEscaped(*port, &payload, sizeof(payload), *env,
+                         std::chrono::seconds(2));
   }
 
   size_t HandleBinary(const void *_data, size_t length) {
@@ -205,22 +207,23 @@ private:
   }
 
 protected:
-  virtual void DataReceived(const void *data, size_t length) {
+  bool DataReceived(const void *data, size_t length) noexcept override {
     if (binary) {
       BinaryReceived(data, length);
+      return true;
     } else {
       fwrite(data, 1, length, stdout);
-      PortLineSplitter::DataReceived(data, length);
+      return PortLineSplitter::DataReceived(data, length);
     }
   }
 
-  virtual void LineReceived(const char *_line) {
+  bool LineReceived(const char *_line) noexcept override {
     const char *dollar = strchr(_line, '$');
     if (dollar != NULL)
       _line = dollar;
 
     if (!VerifyNMEAChecksum(_line))
-      return;
+      return true;
 
     NMEAInputLine line(_line);
     char cmd[32];
@@ -230,6 +233,8 @@ protected:
       PFLAC(line);
     else if (strcmp(cmd, "$PFLAX") == 0)
       PFLAX();
+
+    return true;
   }
 };
 
