@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -23,14 +23,15 @@ Copyright_License {
 
 #include "Profile/Profile.hpp"
 #include "Profile/ProfileKeys.hpp"
+#include "system/Path.hpp"
 
 void
-Profile::Save()
+Profile::Save() noexcept
 {
 }
 
 void
-Profile::SetFiles(const TCHAR* override)
+Profile::SetFiles(Path override_path)
 {
 }
 
@@ -52,9 +53,8 @@ Profile::Set(const char *key, const char *value)
 {
 }
 
-bool
-Profile::GetPath(const char *key, TCHAR *value)
+AllocatedPath
+Profile::GetPath(const char *key)
 {
-  *value = _T('\0');
-  return false;
+  return nullptr;
 }
