@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -37,5 +37,5 @@ Main()
   if (!AngleEntryDialog(_T("The caption"), value))
     return;
 
-  printf("%u\n", uround(value.Degrees()));
+  printf("%ld\n", lround(value.Degrees()));
 }
