@@ -30,7 +30,7 @@ Copyright_License {
 #include <stdio.h>
 
 static void
-LogEvent(const TCHAR *event, double time, const GeoPoint &location)
+LogEvent(const TCHAR *event, TimeStamp time, const GeoPoint &location) noexcept
 {
   TCHAR time_buffer[32];
   FormatTime(time_buffer, time);
@@ -58,11 +58,11 @@ int main(int argc, char **argv)
       LogEvent(_T("take-off"), flight.takeoff_time, flight.takeoff_location);
     else if (!flight.flying && last_flying)
       LogEvent(_T("landing"), flight.landing_time, flight.landing_location);
-    else if (flight.release_time >= 0 && !last_released)
+    else if (flight.release_time.IsDefined() && !last_released)
       LogEvent(_T("release"), flight.release_time, flight.release_location);
 
     last_flying = flight.flying;
-    last_released = flight.release_time >= 0;
+    last_released = flight.release_time.IsDefined();
   }
 
   const FlyingState &flight = replay->Calculated().flight;
