@@ -1,7 +1,7 @@
 /* Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -20,9 +20,8 @@
 }
 */
 
-#include "OS/FileUtil.hpp"
+#include "system/FileUtil.hpp"
 #include "TestUtil.hpp"
-#include "Util/StringAPI.hxx"
 
 class TestingFileVisitor: public File::Visitor
 {
@@ -35,15 +34,15 @@ public:
     recursive(_recursive), filtered(_filtered) {}
 
   void
-  Visit(const TCHAR* path, const TCHAR* filename)
+  Visit(Path path, Path filename)
   {
-    if (StringIsEqual(filename, _T("a.txt"))) {
+    if (filename == Path(_T("a.txt"))) {
       ok(true, "a.txt");
-    } else if (StringIsEqual(filename, _T("b.txt"))) {
+    } else if (filename == Path(_T("b.txt"))) {
       ok(true, "b.txt");
-    } else if (StringIsEqual(filename, _T("c.tx"))) {
+    } else if (filename == Path(_T("c.tx"))) {
       ok(!filtered, "c.tx");
-    } else if (StringIsEqual(filename, _T("d.txt"))) {
+    } else if (filename == Path(_T("d.txt"))) {
       ok(recursive, "d.txt");
     } else {
       ok(false, "unexpected file");
@@ -55,24 +54,24 @@ int main(int argc, char **argv)
 {
   plan_tests(17);
 
-  ok1(Directory::Exists(_T("test/data/file_visitor_test")));
-  ok1(File::Exists(_T("test/data/file_visitor_test/a.txt")));
-  ok1(File::Exists(_T("test/data/file_visitor_test/b.txt")));
-  ok1(File::Exists(_T("test/data/file_visitor_test/c.tx")));
-  ok1(File::Exists(_T("test/data/file_visitor_test/subfolder/d.txt")));
+  ok1(Directory::Exists(Path(_T("test/data/file_visitor_test"))));
+  ok1(File::Exists(Path(_T("test/data/file_visitor_test/a.txt"))));
+  ok1(File::Exists(Path(_T("test/data/file_visitor_test/b.txt"))));
+  ok1(File::Exists(Path(_T("test/data/file_visitor_test/c.tx"))));
+  ok1(File::Exists(Path(_T("test/data/file_visitor_test/subfolder/d.txt"))));
 
   TestingFileVisitor fv1(false, false);
-  Directory::VisitFiles(_T("test/data/file_visitor_test"), fv1, false);
+  Directory::VisitFiles(Path(_T("test/data/file_visitor_test")), fv1, false);
 
   TestingFileVisitor fv2(true, false);
-  Directory::VisitFiles(_T("test/data/file_visitor_test"), fv2, true);
+  Directory::VisitFiles(Path(_T("test/data/file_visitor_test")), fv2, true);
 
   TestingFileVisitor fv3(false, true);
-  Directory::VisitSpecificFiles(_T("test/data/file_visitor_test"),
+  Directory::VisitSpecificFiles(Path(_T("test/data/file_visitor_test")),
                                 _T("*.txt"), fv3, false);
 
   TestingFileVisitor fv4(true, true);
-  Directory::VisitSpecificFiles(_T("test/data/file_visitor_test"),
+  Directory::VisitSpecificFiles(Path(_T("test/data/file_visitor_test")),
                                 _T("*.txt"), fv4, true);
 
   return exit_status();
