@@ -1,7 +1,7 @@
 /* Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -21,8 +21,8 @@
 */
 
 #include "Formatter/IGCFilenameFormatter.hpp"
-#include "Util/StringAPI.hxx"
-#include "Time/BrokenDate.hpp"
+#include "util/StringAPI.hxx"
+#include "time/BrokenDate.hpp"
 #include "TestUtil.hpp"
 
 static void
