@@ -1,7 +1,7 @@
 /* Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -20,8 +20,8 @@
 }
 */
 
-#include "Util/StringAPI.hxx"
-#include "Util/StringUtil.hpp"
+#include "util/StringAPI.hxx"
+#include "util/StringCompare.hxx"
 #include "TestUtil.hpp"
 
 #include <tchar.h>
