@@ -1,7 +1,7 @@
 /* Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -71,7 +71,7 @@ test_effective_mc(int test_num, int n_wind)
   ok(ce0 > ce3, GetTestName("emc speed fast", test_num, n_wind), 0);
 
   // higher than expected cruise sink
-  autopilot_parms.sink_factor = fixed(1.2);
+  autopilot_parms.sink_factor = 1.2;
   result = test_flight(test_num, n_wind);
   ce4 = result.calc_effective_mc;
   if (ce0 <= ce4 || verbose)
@@ -79,10 +79,10 @@ test_effective_mc(int test_num, int n_wind)
 
   ok(ce0 > ce4, GetTestName("emc high sink", test_num, n_wind), 0);
   // effective mc of this should be lower than nominal
-  autopilot_parms.sink_factor = fixed(1.0);
+  autopilot_parms.sink_factor = 1.0;
 
   // slower than expected climb
-  autopilot_parms.climb_factor = fixed(0.8);
+  autopilot_parms.climb_factor = 0.8;
   result = test_flight(test_num, n_wind);
   ce5 = result.calc_effective_mc;
   if (ce0 <= ce5 || verbose)
@@ -90,10 +90,10 @@ test_effective_mc(int test_num, int n_wind)
 
   ok(ce0 > ce5, GetTestName("emc slow climb", test_num, n_wind), 0);
   // effective mc of this should be lower than nominal
-  autopilot_parms.climb_factor = fixed(1.0);
+  autopilot_parms.climb_factor = 1.0;
 
   // lower than expected cruise sink;
-  autopilot_parms.sink_factor = fixed(0.8);
+  autopilot_parms.sink_factor = 0.8;
   result = test_flight(test_num, n_wind);
   ce6 = result.calc_effective_mc;
   if (ce0 >= ce6 || verbose)
@@ -101,7 +101,7 @@ test_effective_mc(int test_num, int n_wind)
 
   ok(ce0 < ce6, GetTestName("emc low sink", test_num, n_wind), 0);
   // effective mc of this should be greater than nominal
-  autopilot_parms.sink_factor = fixed(1.0);
+  autopilot_parms.sink_factor = 1.0;
 
   bool retval = (ce0 > ce1) &&
                 (ce0 > ce2) &&
