@@ -45,7 +45,7 @@ public:
   AircraftState state;
 
   void print(std::ostream &f) {
-    f << (double)state.time << " " 
+    f << (double)state.time.ToDuration().count() << " "
       <<  (double)state.location.longitude.Degrees() << " "
       <<  (double)state.location.latitude.Degrees() << " "
       <<  (double)state.altitude << "\n";
@@ -58,14 +58,14 @@ protected:
 
   void OnAdvance(const GeoPoint &loc,
                  const double speed, const Angle bearing,
-                 const double alt, const double baroalt, const double t) {
-
+                 const double alt, const double baroalt,
+                 const TimeStamp t) noexcept {
     state.location = loc;
     state.ground_speed = speed;
     state.track = bearing;
     state.altitude = alt;
     state.time = t;
-    if (t > 0) {
+    if (t.ToDuration().count() > 0) {
       started = true;
     }
   }
@@ -162,15 +162,15 @@ test_replay()
 
   if (verbose) {
     PrintDistanceCounts();
-    printf("# task elapsed %d (s)\n", (int)task_manager.GetStats().total.time_elapsed);
+    printf("# task elapsed %d (s)\n", (int)task_manager.GetStats().total.time_elapsed.count());
     printf("# task speed %3.1f (kph)\n", (int)task_manager.GetStats().total.travelled.GetSpeed()*3.6);
     printf("# travelled distance %4.1f (km)\n", 
            (double)task_manager.GetStats().total.travelled.GetDistance()/1000.0);
     printf("# scored distance %4.1f (km)\n", 
            (double)task_manager.GetStats().distance_scored/1000.0);
-    if (task_manager.GetStats().total.time_elapsed > 0) {
+    if (task_manager.GetStats().total.time_elapsed.count() > 0) {
       printf("# scored speed %3.1f (kph)\n", 
-             (double)task_manager.GetStats().distance_scored/(double)task_manager.GetStats().total.time_elapsed*3.6);
+             (double)task_manager.GetStats().distance_scored/(double)task_manager.GetStats().total.time_elapsed.count()*3.6);
     }
   }
   return true;
